# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.av1_per_title_configuration import Av1PerTitleConfiguration
from bitmovin_api_sdk.models.h264_per_title_configuration import H264PerTitleConfiguration
from bitmovin_api_sdk.models.h265_per_title_configuration import H265PerTitleConfiguration
from bitmovin_api_sdk.models.vp9_per_title_configuration import Vp9PerTitleConfiguration
import pprint
import six


class PerTitle(object):
    @poscheck_model
    def __init__(self,
                 h264_configuration=None,
                 h265_configuration=None,
                 vp9_configuration=None,
                 av1_configuration=None):
        # type: (H264PerTitleConfiguration, H265PerTitleConfiguration, Vp9PerTitleConfiguration, Av1PerTitleConfiguration) -> None

        self._h264_configuration = None
        self._h265_configuration = None
        self._vp9_configuration = None
        self._av1_configuration = None
        self.discriminator = None

        if h264_configuration is not None:
            self.h264_configuration = h264_configuration
        if h265_configuration is not None:
            self.h265_configuration = h265_configuration
        if vp9_configuration is not None:
            self.vp9_configuration = vp9_configuration
        if av1_configuration is not None:
            self.av1_configuration = av1_configuration

    @property
    def openapi_types(self):
        types = {
            'h264_configuration': 'H264PerTitleConfiguration',
            'h265_configuration': 'H265PerTitleConfiguration',
            'vp9_configuration': 'Vp9PerTitleConfiguration',
            'av1_configuration': 'Av1PerTitleConfiguration'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'h264_configuration': 'h264Configuration',
            'h265_configuration': 'h265Configuration',
            'vp9_configuration': 'vp9Configuration',
            'av1_configuration': 'av1Configuration'
        }
        return attributes

    @property
    def h264_configuration(self):
        # type: () -> H264PerTitleConfiguration
        """Gets the h264_configuration of this PerTitle.

        Per-Title configuration for H264

        :return: The h264_configuration of this PerTitle.
        :rtype: H264PerTitleConfiguration
        """
        return self._h264_configuration

    @h264_configuration.setter
    def h264_configuration(self, h264_configuration):
        # type: (H264PerTitleConfiguration) -> None
        """Sets the h264_configuration of this PerTitle.

        Per-Title configuration for H264

        :param h264_configuration: The h264_configuration of this PerTitle.
        :type: H264PerTitleConfiguration
        """

        if h264_configuration is not None:
            if not isinstance(h264_configuration, H264PerTitleConfiguration):
                raise TypeError("Invalid type for `h264_configuration`, type has to be `H264PerTitleConfiguration`")

        self._h264_configuration = h264_configuration

    @property
    def h265_configuration(self):
        # type: () -> H265PerTitleConfiguration
        """Gets the h265_configuration of this PerTitle.

        Per-Title configuration for H265

        :return: The h265_configuration of this PerTitle.
        :rtype: H265PerTitleConfiguration
        """
        return self._h265_configuration

    @h265_configuration.setter
    def h265_configuration(self, h265_configuration):
        # type: (H265PerTitleConfiguration) -> None
        """Sets the h265_configuration of this PerTitle.

        Per-Title configuration for H265

        :param h265_configuration: The h265_configuration of this PerTitle.
        :type: H265PerTitleConfiguration
        """

        if h265_configuration is not None:
            if not isinstance(h265_configuration, H265PerTitleConfiguration):
                raise TypeError("Invalid type for `h265_configuration`, type has to be `H265PerTitleConfiguration`")

        self._h265_configuration = h265_configuration

    @property
    def vp9_configuration(self):
        # type: () -> Vp9PerTitleConfiguration
        """Gets the vp9_configuration of this PerTitle.

        Per-Title configuration for VP9

        :return: The vp9_configuration of this PerTitle.
        :rtype: Vp9PerTitleConfiguration
        """
        return self._vp9_configuration

    @vp9_configuration.setter
    def vp9_configuration(self, vp9_configuration):
        # type: (Vp9PerTitleConfiguration) -> None
        """Sets the vp9_configuration of this PerTitle.

        Per-Title configuration for VP9

        :param vp9_configuration: The vp9_configuration of this PerTitle.
        :type: Vp9PerTitleConfiguration
        """

        if vp9_configuration is not None:
            if not isinstance(vp9_configuration, Vp9PerTitleConfiguration):
                raise TypeError("Invalid type for `vp9_configuration`, type has to be `Vp9PerTitleConfiguration`")

        self._vp9_configuration = vp9_configuration

    @property
    def av1_configuration(self):
        # type: () -> Av1PerTitleConfiguration
        """Gets the av1_configuration of this PerTitle.

        Per-Title configuration for AV1

        :return: The av1_configuration of this PerTitle.
        :rtype: Av1PerTitleConfiguration
        """
        return self._av1_configuration

    @av1_configuration.setter
    def av1_configuration(self, av1_configuration):
        # type: (Av1PerTitleConfiguration) -> None
        """Sets the av1_configuration of this PerTitle.

        Per-Title configuration for AV1

        :param av1_configuration: The av1_configuration of this PerTitle.
        :type: Av1PerTitleConfiguration
        """

        if av1_configuration is not None:
            if not isinstance(av1_configuration, Av1PerTitleConfiguration):
                raise TypeError("Invalid type for `av1_configuration`, type has to be `Av1PerTitleConfiguration`")

        self._av1_configuration = av1_configuration

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PerTitle):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.status import Status
import pprint
import six


class Subtask(BitmovinResponse):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 status=None,
                 progress=None,
                 name=None,
                 messages=None,
                 metadata=None,
                 created_at=None,
                 updated_at=None,
                 started_at=None,
                 queued_at=None,
                 running_at=None,
                 finished_at=None,
                 error_at=None):
        # type: (string_types, Status, int, string_types, list[Message], list[SubtaskMetadata], datetime, datetime, datetime, datetime, datetime, datetime, datetime) -> None
        super(Subtask, self).__init__(id_=id_)

        self._status = None
        self._progress = None
        self._name = None
        self._messages = list()
        self._metadata = list()
        self._created_at = None
        self._updated_at = None
        self._started_at = None
        self._queued_at = None
        self._running_at = None
        self._finished_at = None
        self._error_at = None
        self.discriminator = None

        if status is not None:
            self.status = status
        if progress is not None:
            self.progress = progress
        if name is not None:
            self.name = name
        if messages is not None:
            self.messages = messages
        if metadata is not None:
            self.metadata = metadata
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if started_at is not None:
            self.started_at = started_at
        if queued_at is not None:
            self.queued_at = queued_at
        if running_at is not None:
            self.running_at = running_at
        if finished_at is not None:
            self.finished_at = finished_at
        if error_at is not None:
            self.error_at = error_at

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(Subtask, self), 'openapi_types'):
            types = getattr(super(Subtask, self), 'openapi_types')

        types.update({
            'status': 'Status',
            'progress': 'int',
            'name': 'string_types',
            'messages': 'list[Message]',
            'metadata': 'list[SubtaskMetadata]',
            'created_at': 'datetime',
            'updated_at': 'datetime',
            'started_at': 'datetime',
            'queued_at': 'datetime',
            'running_at': 'datetime',
            'finished_at': 'datetime',
            'error_at': 'datetime'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(Subtask, self), 'attribute_map'):
            attributes = getattr(super(Subtask, self), 'attribute_map')

        attributes.update({
            'status': 'status',
            'progress': 'progress',
            'name': 'name',
            'messages': 'messages',
            'metadata': 'metadata',
            'created_at': 'createdAt',
            'updated_at': 'updatedAt',
            'started_at': 'startedAt',
            'queued_at': 'queuedAt',
            'running_at': 'runningAt',
            'finished_at': 'finishedAt',
            'error_at': 'errorAt'
        })
        return attributes

    @property
    def status(self):
        # type: () -> Status
        """Gets the status of this Subtask.

        Current status (required)

        :return: The status of this Subtask.
        :rtype: Status
        """
        return self._status

    @status.setter
    def status(self, status):
        # type: (Status) -> None
        """Sets the status of this Subtask.

        Current status (required)

        :param status: The status of this Subtask.
        :type: Status
        """

        if status is not None:
            if not isinstance(status, Status):
                raise TypeError("Invalid type for `status`, type has to be `Status`")

        self._status = status

    @property
    def progress(self):
        # type: () -> int
        """Gets the progress of this Subtask.

        Progress in percent

        :return: The progress of this Subtask.
        :rtype: int
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        # type: (int) -> None
        """Sets the progress of this Subtask.

        Progress in percent

        :param progress: The progress of this Subtask.
        :type: int
        """

        if progress is not None:
            if not isinstance(progress, int):
                raise TypeError("Invalid type for `progress`, type has to be `int`")

        self._progress = progress

    @property
    def name(self):
        # type: () -> string_types
        """Gets the name of this Subtask.

        Name of the subtask (required)

        :return: The name of this Subtask.
        :rtype: string_types
        """
        return self._name

    @name.setter
    def name(self, name):
        # type: (string_types) -> None
        """Sets the name of this Subtask.

        Name of the subtask (required)

        :param name: The name of this Subtask.
        :type: string_types
        """

        if name is not None:
            if not isinstance(name, string_types):
                raise TypeError("Invalid type for `name`, type has to be `string_types`")

        self._name = name

    @property
    def messages(self):
        # type: () -> list[Message]
        """Gets the messages of this Subtask.

        Task specific messages

        :return: The messages of this Subtask.
        :rtype: list[Message]
        """
        return self._messages

    @messages.setter
    def messages(self, messages):
        # type: (list) -> None
        """Sets the messages of this Subtask.

        Task specific messages

        :param messages: The messages of this Subtask.
        :type: list[Message]
        """

        if messages is not None:
            if not isinstance(messages, list):
                raise TypeError("Invalid type for `messages`, type has to be `list[Message]`")

        self._messages = messages

    @property
    def metadata(self):
        # type: () -> list[SubtaskMetadata]
        """Gets the metadata of this Subtask.

        Task specific metadata

        :return: The metadata of this Subtask.
        :rtype: list[SubtaskMetadata]
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        # type: (list) -> None
        """Sets the metadata of this Subtask.

        Task specific metadata

        :param metadata: The metadata of this Subtask.
        :type: list[SubtaskMetadata]
        """

        if metadata is not None:
            if not isinstance(metadata, list):
                raise TypeError("Invalid type for `metadata`, type has to be `list[SubtaskMetadata]`")

        self._metadata = metadata

    @property
    def created_at(self):
        # type: () -> datetime
        """Gets the created_at of this Subtask.

        Timestamp when the subtask was created, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ 

        :return: The created_at of this Subtask.
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        # type: (datetime) -> None
        """Sets the created_at of this Subtask.

        Timestamp when the subtask was created, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ 

        :param created_at: The created_at of this Subtask.
        :type: datetime
        """

        if created_at is not None:
            if not isinstance(created_at, datetime):
                raise TypeError("Invalid type for `created_at`, type has to be `datetime`")

        self._created_at = created_at

    @property
    def updated_at(self):
        # type: () -> datetime
        """Gets the updated_at of this Subtask.

        Timestamp when the subtask was last updated, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ 

        :return: The updated_at of this Subtask.
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        # type: (datetime) -> None
        """Sets the updated_at of this Subtask.

        Timestamp when the subtask was last updated, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ 

        :param updated_at: The updated_at of this Subtask.
        :type: datetime
        """

        if updated_at is not None:
            if not isinstance(updated_at, datetime):
                raise TypeError("Invalid type for `updated_at`, type has to be `datetime`")

        self._updated_at = updated_at

    @property
    def started_at(self):
        # type: () -> datetime
        """Gets the started_at of this Subtask.

        Timestamp when the subtask was started, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ 

        :return: The started_at of this Subtask.
        :rtype: datetime
        """
        return self._started_at

    @started_at.setter
    def started_at(self, started_at):
        # type: (datetime) -> None
        """Sets the started_at of this Subtask.

        Timestamp when the subtask was started, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ 

        :param started_at: The started_at of this Subtask.
        :type: datetime
        """

        if started_at is not None:
            if not isinstance(started_at, datetime):
                raise TypeError("Invalid type for `started_at`, type has to be `datetime`")

        self._started_at = started_at

    @property
    def queued_at(self):
        # type: () -> datetime
        """Gets the queued_at of this Subtask.

        Timestamp when the subtask status changed to 'QUEUED', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ 

        :return: The queued_at of this Subtask.
        :rtype: datetime
        """
        return self._queued_at

    @queued_at.setter
    def queued_at(self, queued_at):
        # type: (datetime) -> None
        """Sets the queued_at of this Subtask.

        Timestamp when the subtask status changed to 'QUEUED', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ 

        :param queued_at: The queued_at of this Subtask.
        :type: datetime
        """

        if queued_at is not None:
            if not isinstance(queued_at, datetime):
                raise TypeError("Invalid type for `queued_at`, type has to be `datetime`")

        self._queued_at = queued_at

    @property
    def running_at(self):
        # type: () -> datetime
        """Gets the running_at of this Subtask.

        Timestamp when the subtask status changed to 'RUNNING', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ 

        :return: The running_at of this Subtask.
        :rtype: datetime
        """
        return self._running_at

    @running_at.setter
    def running_at(self, running_at):
        # type: (datetime) -> None
        """Sets the running_at of this Subtask.

        Timestamp when the subtask status changed to 'RUNNING', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ 

        :param running_at: The running_at of this Subtask.
        :type: datetime
        """

        if running_at is not None:
            if not isinstance(running_at, datetime):
                raise TypeError("Invalid type for `running_at`, type has to be `datetime`")

        self._running_at = running_at

    @property
    def finished_at(self):
        # type: () -> datetime
        """Gets the finished_at of this Subtask.

        Timestamp when the subtask status changed to a final state like  'FINISHED', 'ERROR', 'CANCELED', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ  Note that this timestamp might be inaccurate for subtasks which ran prior to the [1.50.0 REST API release](https://bitmovin.com/docs/encoding/changelogs/rest). 

        :return: The finished_at of this Subtask.
        :rtype: datetime
        """
        return self._finished_at

    @finished_at.setter
    def finished_at(self, finished_at):
        # type: (datetime) -> None
        """Sets the finished_at of this Subtask.

        Timestamp when the subtask status changed to a final state like  'FINISHED', 'ERROR', 'CANCELED', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ  Note that this timestamp might be inaccurate for subtasks which ran prior to the [1.50.0 REST API release](https://bitmovin.com/docs/encoding/changelogs/rest). 

        :param finished_at: The finished_at of this Subtask.
        :type: datetime
        """

        if finished_at is not None:
            if not isinstance(finished_at, datetime):
                raise TypeError("Invalid type for `finished_at`, type has to be `datetime`")

        self._finished_at = finished_at

    @property
    def error_at(self):
        # type: () -> datetime
        """Gets the error_at of this Subtask.

        Timestamp when the subtask status changed to 'ERROR', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ  Note that this timestamp is deprecated and is equivalent to finishedAt in case of an 'ERROR'. 

        :return: The error_at of this Subtask.
        :rtype: datetime
        """
        return self._error_at

    @error_at.setter
    def error_at(self, error_at):
        # type: (datetime) -> None
        """Sets the error_at of this Subtask.

        Timestamp when the subtask status changed to 'ERROR', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ  Note that this timestamp is deprecated and is equivalent to finishedAt in case of an 'ERROR'. 

        :param error_at: The error_at of this Subtask.
        :type: datetime
        """

        if error_at is not None:
            if not isinstance(error_at, datetime):
                raise TypeError("Invalid type for `error_at`, type has to be `datetime`")

        self._error_at = error_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(Subtask, self), "to_dict"):
            result = super(Subtask, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Subtask):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.configurations.audio.dolby_digital.dolby_digital_api import DolbyDigitalApi
from bitmovin_api_sdk.encoding.configurations.audio.dolby_digital.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.configurations.audio.dolby_digital.dolby_digital_audio_configuration_list_query_params import DolbyDigitalAudioConfigurationListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.encoding.live.stream_keys.stream_keys_api import StreamKeysApi
from bitmovin_api_sdk.encoding.live.standby_pools.standby_pools_api import StandbyPoolsApi


class LiveApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(LiveApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.stream_keys = StreamKeysApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.standby_pools = StandbyPoolsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )



# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.analytics_error_data import AnalyticsErrorData
import pprint
import six


class AnalyticsErrorDetail(object):
    @poscheck_model
    def __init__(self,
                 error_id=None,
                 time=None,
                 client_time=None,
                 code=None,
                 message=None,
                 error_data=None,
                 severity=None,
                 http_requests=None):
        # type: (int, datetime, datetime, int, string_types, AnalyticsErrorData, string_types, list[AnalyticsHttpRequest]) -> None

        self._error_id = None
        self._time = None
        self._client_time = None
        self._code = None
        self._message = None
        self._error_data = None
        self._severity = None
        self._http_requests = list()
        self.discriminator = None

        if error_id is not None:
            self.error_id = error_id
        if time is not None:
            self.time = time
        if client_time is not None:
            self.client_time = client_time
        if code is not None:
            self.code = code
        if message is not None:
            self.message = message
        if error_data is not None:
            self.error_data = error_data
        if severity is not None:
            self.severity = severity
        if http_requests is not None:
            self.http_requests = http_requests

    @property
    def openapi_types(self):
        types = {
            'error_id': 'int',
            'time': 'datetime',
            'client_time': 'datetime',
            'code': 'int',
            'message': 'string_types',
            'error_data': 'AnalyticsErrorData',
            'severity': 'string_types',
            'http_requests': 'list[AnalyticsHttpRequest]'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'error_id': 'errorId',
            'time': 'time',
            'client_time': 'clientTime',
            'code': 'code',
            'message': 'message',
            'error_data': 'errorData',
            'severity': 'severity',
            'http_requests': 'httpRequests'
        }
        return attributes

    @property
    def error_id(self):
        # type: () -> int
        """Gets the error_id of this AnalyticsErrorDetail.

        Error id

        :return: The error_id of this AnalyticsErrorDetail.
        :rtype: int
        """
        return self._error_id

    @error_id.setter
    def error_id(self, error_id):
        # type: (int) -> None
        """Sets the error_id of this AnalyticsErrorDetail.

        Error id

        :param error_id: The error_id of this AnalyticsErrorDetail.
        :type: int
        """

        if error_id is not None:
            if not isinstance(error_id, int):
                raise TypeError("Invalid type for `error_id`, type has to be `int`")

        self._error_id = error_id

    @property
    def time(self):
        # type: () -> datetime
        """Gets the time of this AnalyticsErrorDetail.

        Server timestamp

        :return: The time of this AnalyticsErrorDetail.
        :rtype: datetime
        """
        return self._time

    @time.setter
    def time(self, time):
        # type: (datetime) -> None
        """Sets the time of this AnalyticsErrorDetail.

        Server timestamp

        :param time: The time of this AnalyticsErrorDetail.
        :type: datetime
        """

        if time is not None:
            if not isinstance(time, datetime):
                raise TypeError("Invalid type for `time`, type has to be `datetime`")

        self._time = time

    @property
    def client_time(self):
        # type: () -> datetime
        """Gets the client_time of this AnalyticsErrorDetail.

        Client timestamp

        :return: The client_time of this AnalyticsErrorDetail.
        :rtype: datetime
        """
        return self._client_time

    @client_time.setter
    def client_time(self, client_time):
        # type: (datetime) -> None
        """Sets the client_time of this AnalyticsErrorDetail.

        Client timestamp

        :param client_time: The client_time of this AnalyticsErrorDetail.
        :type: datetime
        """

        if client_time is not None:
            if not isinstance(client_time, datetime):
                raise TypeError("Invalid type for `client_time`, type has to be `datetime`")

        self._client_time = client_time

    @property
    def code(self):
        # type: () -> int
        """Gets the code of this AnalyticsErrorDetail.

        Error code

        :return: The code of this AnalyticsErrorDetail.
        :rtype: int
        """
        return self._code

    @code.setter
    def code(self, code):
        # type: (int) -> None
        """Sets the code of this AnalyticsErrorDetail.

        Error code

        :param code: The code of this AnalyticsErrorDetail.
        :type: int
        """

        if code is not None:
            if not isinstance(code, int):
                raise TypeError("Invalid type for `code`, type has to be `int`")

        self._code = code

    @property
    def message(self):
        # type: () -> string_types
        """Gets the message of this AnalyticsErrorDetail.

        Error message

        :return: The message of this AnalyticsErrorDetail.
        :rtype: string_types
        """
        return self._message

    @message.setter
    def message(self, message):
        # type: (string_types) -> None
        """Sets the message of this AnalyticsErrorDetail.

        Error message

        :param message: The message of this AnalyticsErrorDetail.
        :type: string_types
        """

        if message is not None:
            if not isinstance(message, string_types):
                raise TypeError("Invalid type for `message`, type has to be `string_types`")

        self._message = message

    @property
    def error_data(self):
        # type: () -> AnalyticsErrorData
        """Gets the error_data of this AnalyticsErrorDetail.


        :return: The error_data of this AnalyticsErrorDetail.
        :rtype: AnalyticsErrorData
        """
        return self._error_data

    @error_data.setter
    def error_data(self, error_data):
        # type: (AnalyticsErrorData) -> None
        """Sets the error_data of this AnalyticsErrorDetail.


        :param error_data: The error_data of this AnalyticsErrorDetail.
        :type: AnalyticsErrorData
        """

        if error_data is not None:
            if not isinstance(error_data, AnalyticsErrorData):
                raise TypeError("Invalid type for `error_data`, type has to be `AnalyticsErrorData`")

        self._error_data = error_data

    @property
    def severity(self):
        # type: () -> string_types
        """Gets the severity of this AnalyticsErrorDetail.

        Severity of the error

        :return: The severity of this AnalyticsErrorDetail.
        :rtype: string_types
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        # type: (string_types) -> None
        """Sets the severity of this AnalyticsErrorDetail.

        Severity of the error

        :param severity: The severity of this AnalyticsErrorDetail.
        :type: string_types
        """

        if severity is not None:
            if not isinstance(severity, string_types):
                raise TypeError("Invalid type for `severity`, type has to be `string_types`")

        self._severity = severity

    @property
    def http_requests(self):
        # type: () -> list[AnalyticsHttpRequest]
        """Gets the http_requests of this AnalyticsErrorDetail.


        :return: The http_requests of this AnalyticsErrorDetail.
        :rtype: list[AnalyticsHttpRequest]
        """
        return self._http_requests

    @http_requests.setter
    def http_requests(self, http_requests):
        # type: (list) -> None
        """Sets the http_requests of this AnalyticsErrorDetail.


        :param http_requests: The http_requests of this AnalyticsErrorDetail.
        :type: list[AnalyticsHttpRequest]
        """

        if http_requests is not None:
            if not isinstance(http_requests, list):
                raise TypeError("Invalid type for `http_requests`, type has to be `list[AnalyticsHttpRequest]`")

        self._http_requests = http_requests

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyticsErrorDetail):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.notifications.emails.emails_api import EmailsApi
from bitmovin_api_sdk.notifications.emails.usage_reports.usage_reports_api import UsageReportsApi
from bitmovin_api_sdk.notifications.emails.encoding.encoding_api import EncodingApi
from bitmovin_api_sdk.notifications.emails.notification_list_query_params import NotificationListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.hls_input import HlsInput
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.inputs.hls.hls_input_list_query_params import HlsInputListQueryParams


class HlsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(HlsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, hls_input, **kwargs):
        # type: (HlsInput, dict) -> HlsInput
        """Create HLS input

        :param hls_input: The HLSInput to be created
        :type hls_input: HlsInput, required
        :return: HLS input
        :rtype: HlsInput
        """

        return self.api_client.post(
            '/encoding/inputs/hls',
            hls_input,
            type=HlsInput,
            **kwargs
        )

    def delete(self, input_id, **kwargs):
        # type: (string_types, dict) -> HlsInput
        """Delete HLS Input

        :param input_id: Id of the input
        :type input_id: string_types, required
        :return: Id of the input
        :rtype: HlsInput
        """

        return self.api_client.delete(
            '/encoding/inputs/hls/{input_id}',
            path_params={'input_id': input_id},
            type=HlsInput,
            **kwargs
        )

    def get(self, input_id, **kwargs):
        # type: (string_types, dict) -> HlsInput
        """HLS Input Details

        :param input_id: Id of the input
        :type input_id: string_types, required
        :return: HLS input
        :rtype: HlsInput
        """

        return self.api_client.get(
            '/encoding/inputs/hls/{input_id}',
            path_params={'input_id': input_id},
            type=HlsInput,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (HlsInputListQueryParams, dict) -> HlsInput
        """List HLS inputs

        :param query_params: Query parameters
        :type query_params: HlsInputListQueryParams
        :return: List of HLS inputs
        :rtype: HlsInput
        """

        return self.api_client.get(
            '/encoding/inputs/hls',
            query_params=query_params,
            pagination_response=True,
            type=HlsInput,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class WebVttStylingMode(Enum):
    PASSTHROUGH = "PASSTHROUGH"
    DROP_STYLING = "DROP_STYLING"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.srt_to_cea608708_caption import SrtToCea608708Caption
from bitmovin_api_sdk.encoding.encodings.streams.captions.cea.srt.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.streams.captions.cea.srt.srt_to_cea608708_caption_list_query_params import SrtToCea608708CaptionListQueryParams


class SrtApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(SrtApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, stream_id, srt_to_cea608708_caption, **kwargs):
        # type: (string_types, string_types, SrtToCea608708Caption, dict) -> SrtToCea608708Caption
        """Embed SRT captions as 608/708 into Stream

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :param srt_to_cea608708_caption: The SRT captions to be embedded as 607/708 into Stream
        :type srt_to_cea608708_caption: SrtToCea608708Caption, required
        :return: Caption resource
        :rtype: SrtToCea608708Caption
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/streams/{stream_id}/captions/608-708/srt',
            srt_to_cea608708_caption,
            path_params={'encoding_id': encoding_id, 'stream_id': stream_id},
            type=SrtToCea608708Caption,
            **kwargs
        )

    def delete(self, encoding_id, stream_id, captions_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> BitmovinResponse
        """Delete SRT captions as 608/708 from Stream

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :param captions_id: Id of the caption.
        :type captions_id: string_types, required
        :return: Id of the caption
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/encodings/{encoding_id}/streams/{stream_id}/captions/608-708/srt/{captions_id}',
            path_params={'encoding_id': encoding_id, 'stream_id': stream_id, 'captions_id': captions_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, encoding_id, stream_id, captions_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> SrtToCea608708Caption
        """Embed SRT captions as 608/708 Details

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :param captions_id: Id of the caption.
        :type captions_id: string_types, required
        :return: Caption
        :rtype: SrtToCea608708Caption
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/streams/{stream_id}/captions/608-708/srt/{captions_id}',
            path_params={'encoding_id': encoding_id, 'stream_id': stream_id, 'captions_id': captions_id},
            type=SrtToCea608708Caption,
            **kwargs
        )

    def list(self, encoding_id, stream_id, query_params=None, **kwargs):
        # type: (string_types, string_types, SrtToCea608708CaptionListQueryParams, dict) -> SrtToCea608708Caption
        """List SRT captions as 608/708 from Stream

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :param query_params: Query parameters
        :type query_params: SrtToCea608708CaptionListQueryParams
        :return: List of caption configurations
        :rtype: SrtToCea608708Caption
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/streams/{stream_id}/captions/608-708/srt',
            path_params={'encoding_id': encoding_id, 'stream_id': stream_id},
            query_params=query_params,
            pagination_response=True,
            type=SrtToCea608708Caption,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class DolbyDigitalChannelLayout(Enum):
    NONE = "NONE"
    MONO = "MONO"
    CL_STEREO = "STEREO"
    CL_SURROUND = "SURROUND"
    CL_3_1 = "3.1"
    CL_BACK_SURROUND = "BACK_SURROUND"
    CL_BACK_SURROUND_LFE = "BACK_SURROUND_LFE"
    CL_QUAD = "QUAD"
    CL_QUAD_LFE = "QUAD_LFE"
    CL_4_0 = "4.0"
    CL_4_1 = "4.1"
    CL_5_0 = "5.0"
    CL_5_1 = "5.1"



from bitmovin_api_sdk.encoding.encodings.streams.burn_in_subtitles.burn_in_subtitles_api import BurnInSubtitlesApi
from bitmovin_api_sdk.encoding.encodings.streams.burn_in_subtitles.dvbsub.dvbsub_api import DvbsubApi
from bitmovin_api_sdk.encoding.encodings.streams.burn_in_subtitles.srt.srt_api import SrtApi
from bitmovin_api_sdk.encoding.encodings.streams.burn_in_subtitles.assa.assa_api import AssaApi



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.pois_endpoint_credentials import PoisEndpointCredentials
import pprint
import six


class EsamSettings(object):
    @poscheck_model
    def __init__(self,
                 pois_endpoint=None,
                 acquisition_point_identity=None,
                 zone_identity=None,
                 ad_avail_offset=None,
                 pois_endpoint_credentials=None):
        # type: (string_types, string_types, string_types, int, PoisEndpointCredentials) -> None

        self._pois_endpoint = None
        self._acquisition_point_identity = None
        self._zone_identity = None
        self._ad_avail_offset = None
        self._pois_endpoint_credentials = None
        self.discriminator = None

        if pois_endpoint is not None:
            self.pois_endpoint = pois_endpoint
        if acquisition_point_identity is not None:
            self.acquisition_point_identity = acquisition_point_identity
        if zone_identity is not None:
            self.zone_identity = zone_identity
        if ad_avail_offset is not None:
            self.ad_avail_offset = ad_avail_offset
        if pois_endpoint_credentials is not None:
            self.pois_endpoint_credentials = pois_endpoint_credentials

    @property
    def openapi_types(self):
        types = {
            'pois_endpoint': 'string_types',
            'acquisition_point_identity': 'string_types',
            'zone_identity': 'string_types',
            'ad_avail_offset': 'int',
            'pois_endpoint_credentials': 'PoisEndpointCredentials'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'pois_endpoint': 'poisEndpoint',
            'acquisition_point_identity': 'acquisitionPointIdentity',
            'zone_identity': 'zoneIdentity',
            'ad_avail_offset': 'adAvailOffset',
            'pois_endpoint_credentials': 'poisEndpointCredentials'
        }
        return attributes

    @property
    def pois_endpoint(self):
        # type: () -> string_types
        """Gets the pois_endpoint of this EsamSettings.

        The URL of the Placement Opportunity Information System (POIS) signal processing endpoint. The encoder transmits SignalProcessingEvents to this endpoint whenever SCTE-35 messages are detected. 

        :return: The pois_endpoint of this EsamSettings.
        :rtype: string_types
        """
        return self._pois_endpoint

    @pois_endpoint.setter
    def pois_endpoint(self, pois_endpoint):
        # type: (string_types) -> None
        """Sets the pois_endpoint of this EsamSettings.

        The URL of the Placement Opportunity Information System (POIS) signal processing endpoint. The encoder transmits SignalProcessingEvents to this endpoint whenever SCTE-35 messages are detected. 

        :param pois_endpoint: The pois_endpoint of this EsamSettings.
        :type: string_types
        """

        if pois_endpoint is not None:
            if not isinstance(pois_endpoint, string_types):
                raise TypeError("Invalid type for `pois_endpoint`, type has to be `string_types`")

        self._pois_endpoint = pois_endpoint

    @property
    def acquisition_point_identity(self):
        # type: () -> string_types
        """Gets the acquisition_point_identity of this EsamSettings.

        A unique identifier representing the `Acquisition Point Identity` defined in the ESAM specification. 

        :return: The acquisition_point_identity of this EsamSettings.
        :rtype: string_types
        """
        return self._acquisition_point_identity

    @acquisition_point_identity.setter
    def acquisition_point_identity(self, acquisition_point_identity):
        # type: (string_types) -> None
        """Sets the acquisition_point_identity of this EsamSettings.

        A unique identifier representing the `Acquisition Point Identity` defined in the ESAM specification. 

        :param acquisition_point_identity: The acquisition_point_identity of this EsamSettings.
        :type: string_types
        """

        if acquisition_point_identity is not None:
            if not isinstance(acquisition_point_identity, string_types):
                raise TypeError("Invalid type for `acquisition_point_identity`, type has to be `string_types`")

        self._acquisition_point_identity = acquisition_point_identity

    @property
    def zone_identity(self):
        # type: () -> string_types
        """Gets the zone_identity of this EsamSettings.

        Specifies the `Zone Identity` defined in the ESAM specification. 

        :return: The zone_identity of this EsamSettings.
        :rtype: string_types
        """
        return self._zone_identity

    @zone_identity.setter
    def zone_identity(self, zone_identity):
        # type: (string_types) -> None
        """Sets the zone_identity of this EsamSettings.

        Specifies the `Zone Identity` defined in the ESAM specification. 

        :param zone_identity: The zone_identity of this EsamSettings.
        :type: string_types
        """

        if zone_identity is not None:
            if not isinstance(zone_identity, string_types):
                raise TypeError("Invalid type for `zone_identity`, type has to be `string_types`")

        self._zone_identity = zone_identity

    @property
    def ad_avail_offset(self):
        # type: () -> int
        """Gets the ad_avail_offset of this EsamSettings.

        Defines an offset (in milliseconds) to be applied to the stream event timestamp. This offset adjusts the `StreamTime` values (such as PTS) associated with ad opportunities or content insertions. It is used to fine-tune timing for embedded SCTE-104/35 messages to ensure precise frame alignment in the transport stream. 

        :return: The ad_avail_offset of this EsamSettings.
        :rtype: int
        """
        return self._ad_avail_offset

    @ad_avail_offset.setter
    def ad_avail_offset(self, ad_avail_offset):
        # type: (int) -> None
        """Sets the ad_avail_offset of this EsamSettings.

        Defines an offset (in milliseconds) to be applied to the stream event timestamp. This offset adjusts the `StreamTime` values (such as PTS) associated with ad opportunities or content insertions. It is used to fine-tune timing for embedded SCTE-104/35 messages to ensure precise frame alignment in the transport stream. 

        :param ad_avail_offset: The ad_avail_offset of this EsamSettings.
        :type: int
        """

        if ad_avail_offset is not None:
            if ad_avail_offset is not None and ad_avail_offset < 0:
                raise ValueError("Invalid value for `ad_avail_offset`, must be a value greater than or equal to `0`")
            if not isinstance(ad_avail_offset, int):
                raise TypeError("Invalid type for `ad_avail_offset`, type has to be `int`")

        self._ad_avail_offset = ad_avail_offset

    @property
    def pois_endpoint_credentials(self):
        # type: () -> PoisEndpointCredentials
        """Gets the pois_endpoint_credentials of this EsamSettings.

        If authentication is required to access the POIS endpoint, credentials must be provided. 

        :return: The pois_endpoint_credentials of this EsamSettings.
        :rtype: PoisEndpointCredentials
        """
        return self._pois_endpoint_credentials

    @pois_endpoint_credentials.setter
    def pois_endpoint_credentials(self, pois_endpoint_credentials):
        # type: (PoisEndpointCredentials) -> None
        """Sets the pois_endpoint_credentials of this EsamSettings.

        If authentication is required to access the POIS endpoint, credentials must be provided. 

        :param pois_endpoint_credentials: The pois_endpoint_credentials of this EsamSettings.
        :type: PoisEndpointCredentials
        """

        if pois_endpoint_credentials is not None:
            if not isinstance(pois_endpoint_credentials, PoisEndpointCredentials):
                raise TypeError("Invalid type for `pois_endpoint_credentials`, type has to be `PoisEndpointCredentials`")

        self._pois_endpoint_credentials = pois_endpoint_credentials

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EsamSettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class StreamMode(Enum):
    STANDARD = "STANDARD"
    PER_TITLE_TEMPLATE = "PER_TITLE_TEMPLATE"
    PER_TITLE_TEMPLATE_FIXED_RESOLUTION = "PER_TITLE_TEMPLATE_FIXED_RESOLUTION"
    PER_TITLE_TEMPLATE_FIXED_RESOLUTION_AND_BITRATE = "PER_TITLE_TEMPLATE_FIXED_RESOLUTION_AND_BITRATE"
    PER_TITLE_RESULT = "PER_TITLE_RESULT"



from bitmovin_api_sdk.encoding.statistics.labels.labels_api import LabelsApi
from bitmovin_api_sdk.encoding.statistics.labels.daily.daily_api import DailyApi
from bitmovin_api_sdk.encoding.statistics.labels.statistics_per_label_list_query_params import StatisticsPerLabelListQueryParams
from bitmovin_api_sdk.encoding.statistics.labels.statistics_per_label_list_by_date_range_query_params import StatisticsPerLabelListByDateRangeQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class ScalingAlgorithm(Enum):
    FAST_BILINEAR = "FAST_BILINEAR"
    BILINEAR = "BILINEAR"
    BICUBIC = "BICUBIC"
    EXPERIMENTAL = "EXPERIMENTAL"
    NEAREST_NEIGHBOR = "NEAREST_NEIGHBOR"
    AVERAGING_AREA = "AVERAGING_AREA"
    BICUBIC_LUMA_BILINEAR_CHROMA = "BICUBIC_LUMA_BILINEAR_CHROMA"
    GAUSS = "GAUSS"
    SINC = "SINC"
    LANCZOS = "LANCZOS"
    SPLINE = "SPLINE"



# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
import pprint
import six


class BitmovinResource(BitmovinResponse):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict) -> None
        super(BitmovinResource, self).__init__(id_=id_)

        self._name = None
        self._description = None
        self._created_at = None
        self._modified_at = None
        self._custom_data = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at
        if custom_data is not None:
            self.custom_data = custom_data

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(BitmovinResource, self), 'openapi_types'):
            types = getattr(super(BitmovinResource, self), 'openapi_types')

        types.update({
            'name': 'string_types',
            'description': 'string_types',
            'created_at': 'datetime',
            'modified_at': 'datetime',
            'custom_data': 'dict(str, object)'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(BitmovinResource, self), 'attribute_map'):
            attributes = getattr(super(BitmovinResource, self), 'attribute_map')

        attributes.update({
            'name': 'name',
            'description': 'description',
            'created_at': 'createdAt',
            'modified_at': 'modifiedAt',
            'custom_data': 'customData'
        })
        return attributes

    @property
    def name(self):
        # type: () -> string_types
        """Gets the name of this BitmovinResource.

        Name of the resource. Can be freely chosen by the user.

        :return: The name of this BitmovinResource.
        :rtype: string_types
        """
        return self._name

    @name.setter
    def name(self, name):
        # type: (string_types) -> None
        """Sets the name of this BitmovinResource.

        Name of the resource. Can be freely chosen by the user.

        :param name: The name of this BitmovinResource.
        :type: string_types
        """

        if name is not None:
            if not isinstance(name, string_types):
                raise TypeError("Invalid type for `name`, type has to be `string_types`")

        self._name = name

    @property
    def description(self):
        # type: () -> string_types
        """Gets the description of this BitmovinResource.

        Description of the resource. Can be freely chosen by the user.

        :return: The description of this BitmovinResource.
        :rtype: string_types
        """
        return self._description

    @description.setter
    def description(self, description):
        # type: (string_types) -> None
        """Sets the description of this BitmovinResource.

        Description of the resource. Can be freely chosen by the user.

        :param description: The description of this BitmovinResource.
        :type: string_types
        """

        if description is not None:
            if not isinstance(description, string_types):
                raise TypeError("Invalid type for `description`, type has to be `string_types`")

        self._description = description

    @property
    def created_at(self):
        # type: () -> datetime
        """Gets the created_at of this BitmovinResource.

        Creation timestamp, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ

        :return: The created_at of this BitmovinResource.
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        # type: (datetime) -> None
        """Sets the created_at of this BitmovinResource.

        Creation timestamp, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ

        :param created_at: The created_at of this BitmovinResource.
        :type: datetime
        """

        if created_at is not None:
            if not isinstance(created_at, datetime):
                raise TypeError("Invalid type for `created_at`, type has to be `datetime`")

        self._created_at = created_at

    @property
    def modified_at(self):
        # type: () -> datetime
        """Gets the modified_at of this BitmovinResource.

        Modified timestamp, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ

        :return: The modified_at of this BitmovinResource.
        :rtype: datetime
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        # type: (datetime) -> None
        """Sets the modified_at of this BitmovinResource.

        Modified timestamp, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ

        :param modified_at: The modified_at of this BitmovinResource.
        :type: datetime
        """

        if modified_at is not None:
            if not isinstance(modified_at, datetime):
                raise TypeError("Invalid type for `modified_at`, type has to be `datetime`")

        self._modified_at = modified_at

    @property
    def custom_data(self):
        # type: () -> dict(str, object)
        """Gets the custom_data of this BitmovinResource.

        User-specific meta data. This can hold anything.

        :return: The custom_data of this BitmovinResource.
        :rtype: dict(str, object)
        """
        return self._custom_data

    @custom_data.setter
    def custom_data(self, custom_data):
        # type: (dict) -> None
        """Sets the custom_data of this BitmovinResource.

        User-specific meta data. This can hold anything.

        :param custom_data: The custom_data of this BitmovinResource.
        :type: dict(str, object)
        """

        if custom_data is not None:
            if not isinstance(custom_data, dict):
                raise TypeError("Invalid type for `custom_data`, type has to be `dict(str, object)`")

        self._custom_data = custom_data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(BitmovinResource, self), "to_dict"):
            result = super(BitmovinResource, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BitmovinResource):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.transfer_retry import TransferRetry
from bitmovin_api_sdk.encoding.encodings.transfer_retries.transfer_retry_list_query_params import TransferRetryListQueryParams


class TransferRetriesApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(TransferRetriesApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, **kwargs):
        # type: (string_types, dict) -> TransferRetry
        """Transfer retry

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :return: TransferRetry
        :rtype: TransferRetry
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/transfer-retries',
            path_params={'encoding_id': encoding_id},
            type=TransferRetry,
            **kwargs
        )

    def get(self, encoding_id, transfer_retry_id, **kwargs):
        # type: (string_types, string_types, dict) -> TransferRetry
        """Transfer retry Details

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param transfer_retry_id: Id of the transfer-retry.
        :type transfer_retry_id: string_types, required
        :return: TransferRetry
        :rtype: TransferRetry
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/transfer-retries/{transfer_retry_id}',
            path_params={'encoding_id': encoding_id, 'transfer_retry_id': transfer_retry_id},
            type=TransferRetry,
            **kwargs
        )

    def list(self, encoding_id, query_params=None, **kwargs):
        # type: (string_types, TransferRetryListQueryParams, dict) -> TransferRetry
        """List transfer-retries

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param query_params: Query parameters
        :type query_params: TransferRetryListQueryParams
        :return: List of TransferRetry
        :rtype: TransferRetry
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/transfer-retries',
            path_params={'encoding_id': encoding_id},
            query_params=query_params,
            pagination_response=True,
            type=TransferRetry,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class MainSubject(object):
    @poscheck_model
    def __init__(self,
                 classification=None,
                 description=None,
                 appearance_time_in_seconds=None,
                 center_x=None,
                 center_y=None):
        # type: (string_types, string_types, float, float, float) -> None

        self._classification = None
        self._description = None
        self._appearance_time_in_seconds = None
        self._center_x = None
        self._center_y = None
        self.discriminator = None

        if classification is not None:
            self.classification = classification
        if description is not None:
            self.description = description
        if appearance_time_in_seconds is not None:
            self.appearance_time_in_seconds = appearance_time_in_seconds
        if center_x is not None:
            self.center_x = center_x
        if center_y is not None:
            self.center_y = center_y

    @property
    def openapi_types(self):
        types = {
            'classification': 'string_types',
            'description': 'string_types',
            'appearance_time_in_seconds': 'float',
            'center_x': 'float',
            'center_y': 'float'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'classification': 'classification',
            'description': 'description',
            'appearance_time_in_seconds': 'appearanceTimeInSeconds',
            'center_x': 'centerX',
            'center_y': 'centerY'
        }
        return attributes

    @property
    def classification(self):
        # type: () -> string_types
        """Gets the classification of this MainSubject.

        The category or type of the detected subject based on the YOLOv8 OIv7 (Open Images V7) object detection model (e.g., 'person', 'vehicle', 'building') (required)

        :return: The classification of this MainSubject.
        :rtype: string_types
        """
        return self._classification

    @classification.setter
    def classification(self, classification):
        # type: (string_types) -> None
        """Sets the classification of this MainSubject.

        The category or type of the detected subject based on the YOLOv8 OIv7 (Open Images V7) object detection model (e.g., 'person', 'vehicle', 'building') (required)

        :param classification: The classification of this MainSubject.
        :type: string_types
        """

        if classification is not None:
            if not isinstance(classification, string_types):
                raise TypeError("Invalid type for `classification`, type has to be `string_types`")

        self._classification = classification

    @property
    def description(self):
        # type: () -> string_types
        """Gets the description of this MainSubject.

        A detailed textual description of the subject's appearance and characteristics (required)

        :return: The description of this MainSubject.
        :rtype: string_types
        """
        return self._description

    @description.setter
    def description(self, description):
        # type: (string_types) -> None
        """Sets the description of this MainSubject.

        A detailed textual description of the subject's appearance and characteristics (required)

        :param description: The description of this MainSubject.
        :type: string_types
        """

        if description is not None:
            if not isinstance(description, string_types):
                raise TypeError("Invalid type for `description`, type has to be `string_types`")

        self._description = description

    @property
    def appearance_time_in_seconds(self):
        # type: () -> float
        """Gets the appearance_time_in_seconds of this MainSubject.

        The timestamp in seconds when this subject first appears or is most prominently visible in the shot (required)

        :return: The appearance_time_in_seconds of this MainSubject.
        :rtype: float
        """
        return self._appearance_time_in_seconds

    @appearance_time_in_seconds.setter
    def appearance_time_in_seconds(self, appearance_time_in_seconds):
        # type: (float) -> None
        """Sets the appearance_time_in_seconds of this MainSubject.

        The timestamp in seconds when this subject first appears or is most prominently visible in the shot (required)

        :param appearance_time_in_seconds: The appearance_time_in_seconds of this MainSubject.
        :type: float
        """

        if appearance_time_in_seconds is not None:
            if not isinstance(appearance_time_in_seconds, (float, int)):
                raise TypeError("Invalid type for `appearance_time_in_seconds`, type has to be `float`")

        self._appearance_time_in_seconds = appearance_time_in_seconds

    @property
    def center_x(self):
        # type: () -> float
        """Gets the center_x of this MainSubject.

        The horizontal center position of the subject as a percentage from the left edge (0-100, where 0 is the left edge and 100 is the right edge) (required)

        :return: The center_x of this MainSubject.
        :rtype: float
        """
        return self._center_x

    @center_x.setter
    def center_x(self, center_x):
        # type: (float) -> None
        """Sets the center_x of this MainSubject.

        The horizontal center position of the subject as a percentage from the left edge (0-100, where 0 is the left edge and 100 is the right edge) (required)

        :param center_x: The center_x of this MainSubject.
        :type: float
        """

        if center_x is not None:
            if not isinstance(center_x, (float, int)):
                raise TypeError("Invalid type for `center_x`, type has to be `float`")

        self._center_x = center_x

    @property
    def center_y(self):
        # type: () -> float
        """Gets the center_y of this MainSubject.

        The vertical center position of the subject as a percentage from the top edge (0-100, where 0 is the top edge and 100 is the bottom edge) (required)

        :return: The center_y of this MainSubject.
        :rtype: float
        """
        return self._center_y

    @center_y.setter
    def center_y(self, center_y):
        # type: (float) -> None
        """Sets the center_y of this MainSubject.

        The vertical center position of the subject as a percentage from the top edge (0-100, where 0 is the top edge and 100 is the bottom edge) (required)

        :param center_y: The center_y of this MainSubject.
        :type: float
        """

        if center_y is not None:
            if not isinstance(center_y, (float, int)):
                raise TypeError("Invalid type for `center_y`, type has to be `float`")

        self._center_y = center_y

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MainSubject):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.infrastructure.prewarmed_encoder_pools.prewarmed_encoder_pools_api import PrewarmedEncoderPoolsApi
from bitmovin_api_sdk.encoding.infrastructure.prewarmed_encoder_pools.schedules.schedules_api import SchedulesApi
from bitmovin_api_sdk.encoding.infrastructure.prewarmed_encoder_pools.prewarmed_encoder_pool_list_query_params import PrewarmedEncoderPoolListQueryParams



from bitmovin_api_sdk.encoding.encodings.encodings_api import EncodingsApi
from bitmovin_api_sdk.encoding.encodings.live.live_api import LiveApi
from bitmovin_api_sdk.encoding.encodings.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.streams.streams_api import StreamsApi
from bitmovin_api_sdk.encoding.encodings.input_streams.input_streams_api import InputStreamsApi
from bitmovin_api_sdk.encoding.encodings.muxings.muxings_api import MuxingsApi
from bitmovin_api_sdk.encoding.encodings.template.template_api import TemplateApi
from bitmovin_api_sdk.encoding.encodings.transfer_retries.transfer_retries_api import TransferRetriesApi
from bitmovin_api_sdk.encoding.encodings.output_paths.output_paths_api import OutputPathsApi
from bitmovin_api_sdk.encoding.encodings.captions.captions_api import CaptionsApi
from bitmovin_api_sdk.encoding.encodings.sidecars.sidecars_api import SidecarsApi
from bitmovin_api_sdk.encoding.encodings.keyframes.keyframes_api import KeyframesApi
from bitmovin_api_sdk.encoding.encodings.scte35_triggers.scte35_triggers_api import Scte35TriggersApi
from bitmovin_api_sdk.encoding.encodings.encoding_list_query_params import EncodingListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.message import Message
from bitmovin_api_sdk.models.status import Status
import pprint
import six


class CustomPlayerBuildStatus(object):
    @poscheck_model
    def __init__(self,
                 status=None,
                 eta=None,
                 progress=None,
                 messages=None,
                 subtasks=None):
        # type: (Status, int, int, Message, string_types) -> None

        self._status = None
        self._eta = None
        self._progress = None
        self._messages = None
        self._subtasks = None
        self.discriminator = None

        if status is not None:
            self.status = status
        if eta is not None:
            self.eta = eta
        if progress is not None:
            self.progress = progress
        if messages is not None:
            self.messages = messages
        if subtasks is not None:
            self.subtasks = subtasks

    @property
    def openapi_types(self):
        types = {
            'status': 'Status',
            'eta': 'int',
            'progress': 'int',
            'messages': 'Message',
            'subtasks': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'status': 'status',
            'eta': 'eta',
            'progress': 'progress',
            'messages': 'messages',
            'subtasks': 'subtasks'
        }
        return attributes

    @property
    def status(self):
        # type: () -> Status
        """Gets the status of this CustomPlayerBuildStatus.

        Status of the player build (required)

        :return: The status of this CustomPlayerBuildStatus.
        :rtype: Status
        """
        return self._status

    @status.setter
    def status(self, status):
        # type: (Status) -> None
        """Sets the status of this CustomPlayerBuildStatus.

        Status of the player build (required)

        :param status: The status of this CustomPlayerBuildStatus.
        :type: Status
        """

        if status is not None:
            if not isinstance(status, Status):
                raise TypeError("Invalid type for `status`, type has to be `Status`")

        self._status = status

    @property
    def eta(self):
        # type: () -> int
        """Gets the eta of this CustomPlayerBuildStatus.

        The estimated time span of the custom player build in seconds.

        :return: The eta of this CustomPlayerBuildStatus.
        :rtype: int
        """
        return self._eta

    @eta.setter
    def eta(self, eta):
        # type: (int) -> None
        """Sets the eta of this CustomPlayerBuildStatus.

        The estimated time span of the custom player build in seconds.

        :param eta: The eta of this CustomPlayerBuildStatus.
        :type: int
        """

        if eta is not None:
            if not isinstance(eta, int):
                raise TypeError("Invalid type for `eta`, type has to be `int`")

        self._eta = eta

    @property
    def progress(self):
        # type: () -> int
        """Gets the progress of this CustomPlayerBuildStatus.

        The actual progress of the custom player build. (required)

        :return: The progress of this CustomPlayerBuildStatus.
        :rtype: int
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        # type: (int) -> None
        """Sets the progress of this CustomPlayerBuildStatus.

        The actual progress of the custom player build. (required)

        :param progress: The progress of this CustomPlayerBuildStatus.
        :type: int
        """

        if progress is not None:
            if not isinstance(progress, int):
                raise TypeError("Invalid type for `progress`, type has to be `int`")

        self._progress = progress

    @property
    def messages(self):
        # type: () -> Message
        """Gets the messages of this CustomPlayerBuildStatus.


        :return: The messages of this CustomPlayerBuildStatus.
        :rtype: Message
        """
        return self._messages

    @messages.setter
    def messages(self, messages):
        # type: (Message) -> None
        """Sets the messages of this CustomPlayerBuildStatus.


        :param messages: The messages of this CustomPlayerBuildStatus.
        :type: Message
        """

        if messages is not None:
            if not isinstance(messages, Message):
                raise TypeError("Invalid type for `messages`, type has to be `Message`")

        self._messages = messages

    @property
    def subtasks(self):
        # type: () -> string_types
        """Gets the subtasks of this CustomPlayerBuildStatus.


        :return: The subtasks of this CustomPlayerBuildStatus.
        :rtype: string_types
        """
        return self._subtasks

    @subtasks.setter
    def subtasks(self, subtasks):
        # type: (string_types) -> None
        """Sets the subtasks of this CustomPlayerBuildStatus.


        :param subtasks: The subtasks of this CustomPlayerBuildStatus.
        :type: string_types
        """

        if subtasks is not None:
            if not isinstance(subtasks, string_types):
                raise TypeError("Invalid type for `subtasks`, type has to be `string_types`")

        self._subtasks = subtasks

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CustomPlayerBuildStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.live.standby_pools.standby_pools_api import StandbyPoolsApi
from bitmovin_api_sdk.encoding.live.standby_pools.actions.actions_api import ActionsApi
from bitmovin_api_sdk.encoding.live.standby_pools.encodings.encodings_api import EncodingsApi
from bitmovin_api_sdk.encoding.live.standby_pools.logs.logs_api import LogsApi



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class DolbyVisionMetadataSource(Enum):
    INPUT_STREAM = "INPUT_STREAM"
    EMBEDDED = "EMBEDDED"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class OutputType(Enum):
    AKAMAI_NETSTORAGE = "AKAMAI_NETSTORAGE"
    AZURE = "AZURE"
    GENERIC_S3 = "GENERIC_S3"
    GCS = "GCS"
    FTP = "FTP"
    LOCAL = "LOCAL"
    S3 = "S3"
    S3_ROLE_BASED = "S3_ROLE_BASED"
    SFTP = "SFTP"
    AKAMAI_MSL = "AKAMAI_MSL"
    LIVE_MEDIA_INGEST = "LIVE_MEDIA_INGEST"
    GCS_SERVICE_ACCOUNT = "GCS_SERVICE_ACCOUNT"
    CDN = "CDN"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.filter import Filter
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.filters.type.type_api import TypeApi
from bitmovin_api_sdk.encoding.filters.conform.conform_api import ConformApi
from bitmovin_api_sdk.encoding.filters.watermark.watermark_api import WatermarkApi
from bitmovin_api_sdk.encoding.filters.audio_volume.audio_volume_api import AudioVolumeApi
from bitmovin_api_sdk.encoding.filters.azure_speech_to_captions.azure_speech_to_captions_api import AzureSpeechToCaptionsApi
from bitmovin_api_sdk.encoding.filters.enhanced_watermark.enhanced_watermark_api import EnhancedWatermarkApi
from bitmovin_api_sdk.encoding.filters.crop.crop_api import CropApi
from bitmovin_api_sdk.encoding.filters.rotate.rotate_api import RotateApi
from bitmovin_api_sdk.encoding.filters.deinterlace.deinterlace_api import DeinterlaceApi
from bitmovin_api_sdk.encoding.filters.enhanced_deinterlace.enhanced_deinterlace_api import EnhancedDeinterlaceApi
from bitmovin_api_sdk.encoding.filters.audio_mix.audio_mix_api import AudioMixApi
from bitmovin_api_sdk.encoding.filters.denoise_hqdn3d.denoise_hqdn3d_api import DenoiseHqdn3dApi
from bitmovin_api_sdk.encoding.filters.ebu_r128_single_pass.ebu_r128_single_pass_api import EbuR128SinglePassApi
from bitmovin_api_sdk.encoding.filters.text.text_api import TextApi
from bitmovin_api_sdk.encoding.filters.interlace.interlace_api import InterlaceApi
from bitmovin_api_sdk.encoding.filters.unsharp.unsharp_api import UnsharpApi
from bitmovin_api_sdk.encoding.filters.scale.scale_api import ScaleApi
from bitmovin_api_sdk.encoding.filters.filter_list_query_params import FilterListQueryParams


class FiltersApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(FiltersApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.type = TypeApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.conform = ConformApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.watermark = WatermarkApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.audio_volume = AudioVolumeApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.azure_speech_to_captions = AzureSpeechToCaptionsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.enhanced_watermark = EnhancedWatermarkApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.crop = CropApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.rotate = RotateApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.deinterlace = DeinterlaceApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.enhanced_deinterlace = EnhancedDeinterlaceApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.audio_mix = AudioMixApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.denoise_hqdn3d = DenoiseHqdn3dApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.ebu_r128_single_pass = EbuR128SinglePassApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.text = TextApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.interlace = InterlaceApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.unsharp = UnsharpApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.scale = ScaleApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def get(self, filter_id, **kwargs):
        # type: (string_types, dict) -> Filter
        """Get Filter Details

        :param filter_id: Id of the filter
        :type filter_id: string_types, required
        :return: Filter details
        :rtype: Filter
        """

        return self.api_client.get(
            '/encoding/filters/{filter_id}',
            path_params={'filter_id': filter_id},
            type=Filter,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (FilterListQueryParams, dict) -> Filter
        """List all Filters

        :param query_params: Query parameters
        :type query_params: FilterListQueryParams
        :return: All filters with type information
        :rtype: Filter
        """

        return self.api_client.get(
            '/encoding/filters',
            query_params=query_params,
            pagination_response=True,
            type=Filter,
            **kwargs
        )



from bitmovin_api_sdk.encoding.filters.audio_mix.audio_mix_api import AudioMixApi
from bitmovin_api_sdk.encoding.filters.audio_mix.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.filters.audio_mix.audio_mix_filter_list_query_params import AudioMixFilterListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class Rating(object):
    @poscheck_model
    def __init__(self,
                 region=None,
                 system=None,
                 rating=None):
        # type: (string_types, string_types, string_types) -> None

        self._region = None
        self._system = None
        self._rating = None
        self.discriminator = None

        if region is not None:
            self.region = region
        if system is not None:
            self.system = system
        if rating is not None:
            self.rating = rating

    @property
    def openapi_types(self):
        types = {
            'region': 'string_types',
            'system': 'string_types',
            'rating': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'region': 'region',
            'system': 'system',
            'rating': 'rating'
        }
        return attributes

    @property
    def region(self):
        # type: () -> string_types
        """Gets the region of this Rating.


        :return: The region of this Rating.
        :rtype: string_types
        """
        return self._region

    @region.setter
    def region(self, region):
        # type: (string_types) -> None
        """Sets the region of this Rating.


        :param region: The region of this Rating.
        :type: string_types
        """

        if region is not None:
            if not isinstance(region, string_types):
                raise TypeError("Invalid type for `region`, type has to be `string_types`")

        self._region = region

    @property
    def system(self):
        # type: () -> string_types
        """Gets the system of this Rating.


        :return: The system of this Rating.
        :rtype: string_types
        """
        return self._system

    @system.setter
    def system(self, system):
        # type: (string_types) -> None
        """Sets the system of this Rating.


        :param system: The system of this Rating.
        :type: string_types
        """

        if system is not None:
            if not isinstance(system, string_types):
                raise TypeError("Invalid type for `system`, type has to be `string_types`")

        self._system = system

    @property
    def rating(self):
        # type: () -> string_types
        """Gets the rating of this Rating.


        :return: The rating of this Rating.
        :rtype: string_types
        """
        return self._rating

    @rating.setter
    def rating(self, rating):
        # type: (string_types) -> None
        """Sets the rating of this Rating.


        :param rating: The rating of this Rating.
        :type: string_types
        """

        if rating is not None:
            if not isinstance(rating, string_types):
                raise TypeError("Invalid type for `rating`, type has to be `string_types`")

        self._rating = rating

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Rating):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class PassthroughMode(Enum):
    VIDEO_STREAM = "VIDEO_STREAM"
    CAPTION_STREAM = "CAPTION_STREAM"
    VIDEO_CAPTION_STREAM = "VIDEO_CAPTION_STREAM"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.akamai_account import AkamaiAccount
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.infrastructure.akamai.regions.regions_api import RegionsApi
from bitmovin_api_sdk.encoding.infrastructure.akamai.akamai_account_list_query_params import AkamaiAccountListQueryParams


class AkamaiApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(AkamaiApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.regions = RegionsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, akamai_account, **kwargs):
        # type: (AkamaiAccount, dict) -> AkamaiAccount
        """Add Akamai account

        :param akamai_account: The Akamai account to be added
        :type akamai_account: AkamaiAccount, required
        :return: Akamai account
        :rtype: AkamaiAccount
        """

        return self.api_client.post(
            '/encoding/infrastructure/akamai',
            akamai_account,
            type=AkamaiAccount,
            **kwargs
        )

    def delete(self, infrastructure_id, **kwargs):
        # type: (string_types, dict) -> AkamaiAccount
        """Delete Akamai account

        :param infrastructure_id: Id of the Akamai account
        :type infrastructure_id: string_types, required
        :return: Akamai account
        :rtype: AkamaiAccount
        """

        return self.api_client.delete(
            '/encoding/infrastructure/akamai/{infrastructure_id}',
            path_params={'infrastructure_id': infrastructure_id},
            type=AkamaiAccount,
            **kwargs
        )

    def get(self, infrastructure_id, **kwargs):
        # type: (string_types, dict) -> AkamaiAccount
        """Akamai account details

        :param infrastructure_id: Id of the Akamai account
        :type infrastructure_id: string_types, required
        :return: Akamai account
        :rtype: AkamaiAccount
        """

        return self.api_client.get(
            '/encoding/infrastructure/akamai/{infrastructure_id}',
            path_params={'infrastructure_id': infrastructure_id},
            type=AkamaiAccount,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (AkamaiAccountListQueryParams, dict) -> AkamaiAccount
        """List Akamai accounts

        :param query_params: Query parameters
        :type query_params: AkamaiAccountListQueryParams
        :return: List of Akamai accounts
        :rtype: AkamaiAccount
        """

        return self.api_client.get(
            '/encoding/infrastructure/akamai',
            query_params=query_params,
            pagination_response=True,
            type=AkamaiAccount,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.filter import Filter
import pprint
import six


class DenoiseHqdn3dFilter(Filter):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 luma_spatial=None,
                 chroma_spatial=None,
                 luma_tmp=None,
                 chroma_tmp=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, float, float, float, float) -> None
        super(DenoiseHqdn3dFilter, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._luma_spatial = None
        self._chroma_spatial = None
        self._luma_tmp = None
        self._chroma_tmp = None
        self.discriminator = None

        if luma_spatial is not None:
            self.luma_spatial = luma_spatial
        if chroma_spatial is not None:
            self.chroma_spatial = chroma_spatial
        if luma_tmp is not None:
            self.luma_tmp = luma_tmp
        if chroma_tmp is not None:
            self.chroma_tmp = chroma_tmp

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(DenoiseHqdn3dFilter, self), 'openapi_types'):
            types = getattr(super(DenoiseHqdn3dFilter, self), 'openapi_types')

        types.update({
            'luma_spatial': 'float',
            'chroma_spatial': 'float',
            'luma_tmp': 'float',
            'chroma_tmp': 'float'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(DenoiseHqdn3dFilter, self), 'attribute_map'):
            attributes = getattr(super(DenoiseHqdn3dFilter, self), 'attribute_map')

        attributes.update({
            'luma_spatial': 'lumaSpatial',
            'chroma_spatial': 'chromaSpatial',
            'luma_tmp': 'lumaTmp',
            'chroma_tmp': 'chromaTmp'
        })
        return attributes

    @property
    def luma_spatial(self):
        # type: () -> float
        """Gets the luma_spatial of this DenoiseHqdn3dFilter.

        A non-negative floating point number which specifies spatial luma strength. It defaults to 4.0.

        :return: The luma_spatial of this DenoiseHqdn3dFilter.
        :rtype: float
        """
        return self._luma_spatial

    @luma_spatial.setter
    def luma_spatial(self, luma_spatial):
        # type: (float) -> None
        """Sets the luma_spatial of this DenoiseHqdn3dFilter.

        A non-negative floating point number which specifies spatial luma strength. It defaults to 4.0.

        :param luma_spatial: The luma_spatial of this DenoiseHqdn3dFilter.
        :type: float
        """

        if luma_spatial is not None:
            if not isinstance(luma_spatial, (float, int)):
                raise TypeError("Invalid type for `luma_spatial`, type has to be `float`")

        self._luma_spatial = luma_spatial

    @property
    def chroma_spatial(self):
        # type: () -> float
        """Gets the chroma_spatial of this DenoiseHqdn3dFilter.

        A non-negative floating point number which specifies spatial chroma strength. It defaults to 3.0*luma_spatial/4.0.

        :return: The chroma_spatial of this DenoiseHqdn3dFilter.
        :rtype: float
        """
        return self._chroma_spatial

    @chroma_spatial.setter
    def chroma_spatial(self, chroma_spatial):
        # type: (float) -> None
        """Sets the chroma_spatial of this DenoiseHqdn3dFilter.

        A non-negative floating point number which specifies spatial chroma strength. It defaults to 3.0*luma_spatial/4.0.

        :param chroma_spatial: The chroma_spatial of this DenoiseHqdn3dFilter.
        :type: float
        """

        if chroma_spatial is not None:
            if not isinstance(chroma_spatial, (float, int)):
                raise TypeError("Invalid type for `chroma_spatial`, type has to be `float`")

        self._chroma_spatial = chroma_spatial

    @property
    def luma_tmp(self):
        # type: () -> float
        """Gets the luma_tmp of this DenoiseHqdn3dFilter.

        A floating point number which specifies luma temporal strength. It defaults to 6.0*luma_spatial/4.0.

        :return: The luma_tmp of this DenoiseHqdn3dFilter.
        :rtype: float
        """
        return self._luma_tmp

    @luma_tmp.setter
    def luma_tmp(self, luma_tmp):
        # type: (float) -> None
        """Sets the luma_tmp of this DenoiseHqdn3dFilter.

        A floating point number which specifies luma temporal strength. It defaults to 6.0*luma_spatial/4.0.

        :param luma_tmp: The luma_tmp of this DenoiseHqdn3dFilter.
        :type: float
        """

        if luma_tmp is not None:
            if not isinstance(luma_tmp, (float, int)):
                raise TypeError("Invalid type for `luma_tmp`, type has to be `float`")

        self._luma_tmp = luma_tmp

    @property
    def chroma_tmp(self):
        # type: () -> float
        """Gets the chroma_tmp of this DenoiseHqdn3dFilter.

        A floating point number which specifies chroma temporal strength. It defaults to luma_tmp*chroma_spatial/luma_spatial.

        :return: The chroma_tmp of this DenoiseHqdn3dFilter.
        :rtype: float
        """
        return self._chroma_tmp

    @chroma_tmp.setter
    def chroma_tmp(self, chroma_tmp):
        # type: (float) -> None
        """Sets the chroma_tmp of this DenoiseHqdn3dFilter.

        A floating point number which specifies chroma temporal strength. It defaults to luma_tmp*chroma_spatial/luma_spatial.

        :param chroma_tmp: The chroma_tmp of this DenoiseHqdn3dFilter.
        :type: float
        """

        if chroma_tmp is not None:
            if not isinstance(chroma_tmp, (float, int)):
                raise TypeError("Invalid type for `chroma_tmp`, type has to be `float`")

        self._chroma_tmp = chroma_tmp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(DenoiseHqdn3dFilter, self), "to_dict"):
            result = super(DenoiseHqdn3dFilter, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DenoiseHqdn3dFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AdMarkersSource(Enum):
    MANIFEST = "MANIFEST"
    SEGMENTS = "SEGMENTS"



from bitmovin_api_sdk.account.organizations.groups.groups_api import GroupsApi
from bitmovin_api_sdk.account.organizations.groups.tenants.tenants_api import TenantsApi
from bitmovin_api_sdk.account.organizations.groups.invitations.invitations_api import InvitationsApi
from bitmovin_api_sdk.account.organizations.groups.permissions.permissions_api import PermissionsApi
from bitmovin_api_sdk.account.organizations.groups.group_list_query_params import GroupListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.organization_pending_invitation import OrganizationPendingInvitation
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError


class InvitationsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(InvitationsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def list(self, organization_id, **kwargs):
        # type: (string_types, dict) -> OrganizationPendingInvitation
        """List all pending invitations of an org id

        :param organization_id: Id of the organization
        :type organization_id: string_types, required
        :return: List of pending invitations
        :rtype: OrganizationPendingInvitation
        """

        return self.api_client.get(
            '/account/organizations/{organization_id}/invitations',
            path_params={'organization_id': organization_id},
            pagination_response=True,
            type=OrganizationPendingInvitation,
            **kwargs
        )



from bitmovin_api_sdk.encoding.manifests.hls.media.video.video_api import VideoApi
from bitmovin_api_sdk.encoding.manifests.hls.media.video.video_media_info_list_query_params import VideoMediaInfoListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class EncodingType(Enum):
    LIVE = "LIVE"
    VOD = "VOD"
    NONE = "NONE"



from bitmovin_api_sdk.encoding.encodings.streams.captions.cea.cea_api import CeaApi
from bitmovin_api_sdk.encoding.encodings.streams.captions.cea.scc.scc_api import SccApi
from bitmovin_api_sdk.encoding.encodings.streams.captions.cea.srt.srt_api import SrtApi



from bitmovin_api_sdk.encoding.manifests.smooth.smooth_api import SmoothApi
from bitmovin_api_sdk.encoding.manifests.smooth.default.default_api import DefaultApi
from bitmovin_api_sdk.encoding.manifests.smooth.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.manifests.smooth.representations.representations_api import RepresentationsApi
from bitmovin_api_sdk.encoding.manifests.smooth.contentprotection.contentprotection_api import ContentprotectionApi
from bitmovin_api_sdk.encoding.manifests.smooth.smooth_streaming_manifest_list_query_params import SmoothStreamingManifestListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.streams_video_create_request import StreamsVideoCreateRequest
from bitmovin_api_sdk.models.streams_video_response import StreamsVideoResponse
from bitmovin_api_sdk.models.streams_video_update_request import StreamsVideoUpdateRequest
from bitmovin_api_sdk.streams.video.streams_video_response_list_query_params import StreamsVideoResponseListQueryParams


class VideoApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(VideoApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, streams_video_create_request, **kwargs):
        # type: (StreamsVideoCreateRequest, dict) -> StreamsVideoResponse
        """Create new Streams video

        :param streams_video_create_request: Create a new stream.
        :type streams_video_create_request: StreamsVideoCreateRequest, required
        :return: Created vod stream
        :rtype: StreamsVideoResponse
        """

        return self.api_client.post(
            '/streams/video',
            streams_video_create_request,
            type=StreamsVideoResponse,
            **kwargs
        )

    def delete(self, stream_id, **kwargs):
        # type: (string_types, dict) -> None
        """Delete Stream

        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        """

        self.api_client.delete(
            '/streams/video/{stream_id}',
            path_params={'stream_id': stream_id},
            **kwargs
        )

    def get(self, stream_id, **kwargs):
        # type: (string_types, dict) -> StreamsVideoResponse
        """Get Streams video by id

        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :return: stream
        :rtype: StreamsVideoResponse
        """

        return self.api_client.get(
            '/streams/video/{stream_id}',
            path_params={'stream_id': stream_id},
            type=StreamsVideoResponse,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (StreamsVideoResponseListQueryParams, dict) -> StreamsVideoResponse
        """Get paginated list of Streams videos

        :param query_params: Query parameters
        :type query_params: StreamsVideoResponseListQueryParams
        :return: List of all streams
        :rtype: StreamsVideoResponse
        """

        return self.api_client.get(
            '/streams/video',
            query_params=query_params,
            pagination_response=True,
            type=StreamsVideoResponse,
            **kwargs
        )

    def patch_streams_video(self, stream_id, streams_video_update_request, **kwargs):
        # type: (string_types, StreamsVideoUpdateRequest, dict) -> StreamsVideoResponse
        """Partially update video stream by id

        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :param streams_video_update_request: Stream fields to update.
        :type streams_video_update_request: StreamsVideoUpdateRequest, required
        :return:
        :rtype: StreamsVideoResponse
        """

        return self.api_client.patch(
            '/streams/video/{stream_id}',
            streams_video_update_request,
            path_params={'stream_id': stream_id},
            type=StreamsVideoResponse,
            **kwargs
        )



from bitmovin_api_sdk.encoding.live.stream_keys.stream_keys_api import StreamKeysApi
from bitmovin_api_sdk.encoding.live.stream_keys.actions.actions_api import ActionsApi
from bitmovin_api_sdk.encoding.live.stream_keys.stream_key_list_query_params import StreamKeyListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class RaiUnit(Enum):
    NONE = "NONE"
    ALL_PES_PACKETS = "ALL_PES_PACKETS"
    ACQUISITION_POINT_PACKETS = "ACQUISITION_POINT_PACKETS"
    ACCORDING_TO_INPUT = "ACCORDING_TO_INPUT"



from bitmovin_api_sdk.analytics.virtual_licenses.virtual_licenses_api import VirtualLicensesApi
from bitmovin_api_sdk.analytics.virtual_licenses.analytics_virtual_license_list_query_params import AnalyticsVirtualLicenseListQueryParams



from bitmovin_api_sdk.encoding.encodings.input_streams.sidecar.sidecar_api import SidecarApi
from bitmovin_api_sdk.encoding.encodings.input_streams.sidecar.dolby_vision_metadata_ingest.dolby_vision_metadata_ingest_api import DolbyVisionMetadataIngestApi



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class Shot(object):
    @poscheck_model
    def __init__(self,
                 start_in_seconds=None,
                 end_in_seconds=None,
                 detailed_description=None,
                 keywords=None,
                 main_subjects=None):
        # type: (float, float, string_types, list[string_types], list[MainSubject]) -> None

        self._start_in_seconds = None
        self._end_in_seconds = None
        self._detailed_description = None
        self._keywords = list()
        self._main_subjects = list()
        self.discriminator = None

        if start_in_seconds is not None:
            self.start_in_seconds = start_in_seconds
        if end_in_seconds is not None:
            self.end_in_seconds = end_in_seconds
        if detailed_description is not None:
            self.detailed_description = detailed_description
        if keywords is not None:
            self.keywords = keywords
        if main_subjects is not None:
            self.main_subjects = main_subjects

    @property
    def openapi_types(self):
        types = {
            'start_in_seconds': 'float',
            'end_in_seconds': 'float',
            'detailed_description': 'string_types',
            'keywords': 'list[string_types]',
            'main_subjects': 'list[MainSubject]'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'start_in_seconds': 'startInSeconds',
            'end_in_seconds': 'endInSeconds',
            'detailed_description': 'detailedDescription',
            'keywords': 'keywords',
            'main_subjects': 'mainSubjects'
        }
        return attributes

    @property
    def start_in_seconds(self):
        # type: () -> float
        """Gets the start_in_seconds of this Shot.

        The start time of the shot in seconds from the beginning of the video (required)

        :return: The start_in_seconds of this Shot.
        :rtype: float
        """
        return self._start_in_seconds

    @start_in_seconds.setter
    def start_in_seconds(self, start_in_seconds):
        # type: (float) -> None
        """Sets the start_in_seconds of this Shot.

        The start time of the shot in seconds from the beginning of the video (required)

        :param start_in_seconds: The start_in_seconds of this Shot.
        :type: float
        """

        if start_in_seconds is not None:
            if not isinstance(start_in_seconds, (float, int)):
                raise TypeError("Invalid type for `start_in_seconds`, type has to be `float`")

        self._start_in_seconds = start_in_seconds

    @property
    def end_in_seconds(self):
        # type: () -> float
        """Gets the end_in_seconds of this Shot.

        The end time of the shot in seconds from the beginning of the video (required)

        :return: The end_in_seconds of this Shot.
        :rtype: float
        """
        return self._end_in_seconds

    @end_in_seconds.setter
    def end_in_seconds(self, end_in_seconds):
        # type: (float) -> None
        """Sets the end_in_seconds of this Shot.

        The end time of the shot in seconds from the beginning of the video (required)

        :param end_in_seconds: The end_in_seconds of this Shot.
        :type: float
        """

        if end_in_seconds is not None:
            if not isinstance(end_in_seconds, (float, int)):
                raise TypeError("Invalid type for `end_in_seconds`, type has to be `float`")

        self._end_in_seconds = end_in_seconds

    @property
    def detailed_description(self):
        # type: () -> string_types
        """Gets the detailed_description of this Shot.

        A comprehensive textual description of the visual content, action, and context within this shot

        :return: The detailed_description of this Shot.
        :rtype: string_types
        """
        return self._detailed_description

    @detailed_description.setter
    def detailed_description(self, detailed_description):
        # type: (string_types) -> None
        """Sets the detailed_description of this Shot.

        A comprehensive textual description of the visual content, action, and context within this shot

        :param detailed_description: The detailed_description of this Shot.
        :type: string_types
        """

        if detailed_description is not None:
            if not isinstance(detailed_description, string_types):
                raise TypeError("Invalid type for `detailed_description`, type has to be `string_types`")

        self._detailed_description = detailed_description

    @property
    def keywords(self):
        # type: () -> list[string_types]
        """Gets the keywords of this Shot.

        A list of relevant keywords and tags that describe the content, themes, or notable elements in this shot

        :return: The keywords of this Shot.
        :rtype: list[string_types]
        """
        return self._keywords

    @keywords.setter
    def keywords(self, keywords):
        # type: (list) -> None
        """Sets the keywords of this Shot.

        A list of relevant keywords and tags that describe the content, themes, or notable elements in this shot

        :param keywords: The keywords of this Shot.
        :type: list[string_types]
        """

        if keywords is not None:
            if not isinstance(keywords, list):
                raise TypeError("Invalid type for `keywords`, type has to be `list[string_types]`")

        self._keywords = keywords

    @property
    def main_subjects(self):
        # type: () -> list[MainSubject]
        """Gets the main_subjects of this Shot.

        A collection of the primary subjects or objects detected and tracked within this shot, including their positions and characteristics

        :return: The main_subjects of this Shot.
        :rtype: list[MainSubject]
        """
        return self._main_subjects

    @main_subjects.setter
    def main_subjects(self, main_subjects):
        # type: (list) -> None
        """Sets the main_subjects of this Shot.

        A collection of the primary subjects or objects detected and tracked within this shot, including their positions and characteristics

        :param main_subjects: The main_subjects of this Shot.
        :type: list[MainSubject]
        """

        if main_subjects is not None:
            if not isinstance(main_subjects, list):
                raise TypeError("Invalid type for `main_subjects`, type has to be `list[MainSubject]`")

        self._main_subjects = main_subjects

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Shot):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.filters.deinterlace.deinterlace_api import DeinterlaceApi
from bitmovin_api_sdk.encoding.filters.deinterlace.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.filters.deinterlace.deinterlace_filter_list_query_params import DeinterlaceFilterListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.streams_public_signing_key_response import StreamsPublicSigningKeyResponse
from bitmovin_api_sdk.models.streams_signing_key_response import StreamsSigningKeyResponse


class SigningKeysApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(SigningKeysApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, **kwargs):
        # type: (dict) -> StreamsSigningKeyResponse
        """Create new signing-key

        :return: Created vod stream
        :rtype: StreamsSigningKeyResponse
        """

        return self.api_client.post(
            '/streams/signing-keys',
            type=StreamsSigningKeyResponse,
            **kwargs
        )

    def delete(self, key_id, **kwargs):
        # type: (string_types, dict) -> None
        """Delete signing-key

        :param key_id: Id of the signing key.
        :type key_id: string_types, required
        """

        self.api_client.delete(
            '/streams/signing-keys/{key_id}',
            path_params={'key_id': key_id},
            **kwargs
        )

    def get(self, **kwargs):
        # type: (dict) -> StreamsPublicSigningKeyResponse
        """Get list of public signing key ids

        :return:
        :rtype: StreamsPublicSigningKeyResponse
        """

        return self.api_client.get(
            '/streams/signing-keys',
            type=StreamsPublicSigningKeyResponse,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.auto_restart_configuration import AutoRestartConfiguration
from bitmovin_api_sdk.models.cache_control_settings import CacheControlSettings
from bitmovin_api_sdk.models.encoding_mode import EncodingMode
from bitmovin_api_sdk.models.esam_settings import EsamSettings
from bitmovin_api_sdk.models.live_auto_shutdown_configuration import LiveAutoShutdownConfiguration
from bitmovin_api_sdk.models.manifest_generator import ManifestGenerator
from bitmovin_api_sdk.models.reupload_settings import ReuploadSettings
import pprint
import six


class StartLiveEncodingRequest(object):
    @poscheck_model
    def __init__(self,
                 stream_key=None,
                 hls_manifests=None,
                 dash_manifests=None,
                 live_encoding_mode=None,
                 reupload_settings=None,
                 manifest_generator=None,
                 auto_restart_configuration=None,
                 auto_shutdown_configuration=None,
                 esam_settings=None,
                 cache_control_settings=None):
        # type: (string_types, list[LiveHlsManifest], list[LiveDashManifest], EncodingMode, ReuploadSettings, ManifestGenerator, AutoRestartConfiguration, LiveAutoShutdownConfiguration, EsamSettings, CacheControlSettings) -> None

        self._stream_key = None
        self._hls_manifests = list()
        self._dash_manifests = list()
        self._live_encoding_mode = None
        self._reupload_settings = None
        self._manifest_generator = None
        self._auto_restart_configuration = None
        self._auto_shutdown_configuration = None
        self._esam_settings = None
        self._cache_control_settings = None
        self.discriminator = None

        if stream_key is not None:
            self.stream_key = stream_key
        if hls_manifests is not None:
            self.hls_manifests = hls_manifests
        if dash_manifests is not None:
            self.dash_manifests = dash_manifests
        if live_encoding_mode is not None:
            self.live_encoding_mode = live_encoding_mode
        if reupload_settings is not None:
            self.reupload_settings = reupload_settings
        if manifest_generator is not None:
            self.manifest_generator = manifest_generator
        if auto_restart_configuration is not None:
            self.auto_restart_configuration = auto_restart_configuration
        if auto_shutdown_configuration is not None:
            self.auto_shutdown_configuration = auto_shutdown_configuration
        if esam_settings is not None:
            self.esam_settings = esam_settings
        if cache_control_settings is not None:
            self.cache_control_settings = cache_control_settings

    @property
    def openapi_types(self):
        types = {
            'stream_key': 'string_types',
            'hls_manifests': 'list[LiveHlsManifest]',
            'dash_manifests': 'list[LiveDashManifest]',
            'live_encoding_mode': 'EncodingMode',
            'reupload_settings': 'ReuploadSettings',
            'manifest_generator': 'ManifestGenerator',
            'auto_restart_configuration': 'AutoRestartConfiguration',
            'auto_shutdown_configuration': 'LiveAutoShutdownConfiguration',
            'esam_settings': 'EsamSettings',
            'cache_control_settings': 'CacheControlSettings'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'stream_key': 'streamKey',
            'hls_manifests': 'hlsManifests',
            'dash_manifests': 'dashManifests',
            'live_encoding_mode': 'liveEncodingMode',
            'reupload_settings': 'reuploadSettings',
            'manifest_generator': 'manifestGenerator',
            'auto_restart_configuration': 'autoRestartConfiguration',
            'auto_shutdown_configuration': 'autoShutdownConfiguration',
            'esam_settings': 'esamSettings',
            'cache_control_settings': 'cacheControlSettings'
        }
        return attributes

    @property
    def stream_key(self):
        # type: () -> string_types
        """Gets the stream_key of this StartLiveEncodingRequest.

        Key for the stream. (a-zA-Z, 3-20 characters) (required)

        :return: The stream_key of this StartLiveEncodingRequest.
        :rtype: string_types
        """
        return self._stream_key

    @stream_key.setter
    def stream_key(self, stream_key):
        # type: (string_types) -> None
        """Sets the stream_key of this StartLiveEncodingRequest.

        Key for the stream. (a-zA-Z, 3-20 characters) (required)

        :param stream_key: The stream_key of this StartLiveEncodingRequest.
        :type: string_types
        """

        if stream_key is not None:
            if not isinstance(stream_key, string_types):
                raise TypeError("Invalid type for `stream_key`, type has to be `string_types`")

        self._stream_key = stream_key

    @property
    def hls_manifests(self):
        # type: () -> list[LiveHlsManifest]
        """Gets the hls_manifests of this StartLiveEncodingRequest.

        HLS manifests to be generated during the encoding. See [documentation](https://developer.bitmovin.com/encoding/docs/how-to-create-manifests-for-your-encodings#just-in-time-jit)

        :return: The hls_manifests of this StartLiveEncodingRequest.
        :rtype: list[LiveHlsManifest]
        """
        return self._hls_manifests

    @hls_manifests.setter
    def hls_manifests(self, hls_manifests):
        # type: (list) -> None
        """Sets the hls_manifests of this StartLiveEncodingRequest.

        HLS manifests to be generated during the encoding. See [documentation](https://developer.bitmovin.com/encoding/docs/how-to-create-manifests-for-your-encodings#just-in-time-jit)

        :param hls_manifests: The hls_manifests of this StartLiveEncodingRequest.
        :type: list[LiveHlsManifest]
        """

        if hls_manifests is not None:
            if not isinstance(hls_manifests, list):
                raise TypeError("Invalid type for `hls_manifests`, type has to be `list[LiveHlsManifest]`")

        self._hls_manifests = hls_manifests

    @property
    def dash_manifests(self):
        # type: () -> list[LiveDashManifest]
        """Gets the dash_manifests of this StartLiveEncodingRequest.

        DASH manifests to be generated during the encoding. See [documentation](https://developer.bitmovin.com/encoding/docs/how-to-create-manifests-for-your-encodings#just-in-time-jit)

        :return: The dash_manifests of this StartLiveEncodingRequest.
        :rtype: list[LiveDashManifest]
        """
        return self._dash_manifests

    @dash_manifests.setter
    def dash_manifests(self, dash_manifests):
        # type: (list) -> None
        """Sets the dash_manifests of this StartLiveEncodingRequest.

        DASH manifests to be generated during the encoding. See [documentation](https://developer.bitmovin.com/encoding/docs/how-to-create-manifests-for-your-encodings#just-in-time-jit)

        :param dash_manifests: The dash_manifests of this StartLiveEncodingRequest.
        :type: list[LiveDashManifest]
        """

        if dash_manifests is not None:
            if not isinstance(dash_manifests, list):
                raise TypeError("Invalid type for `dash_manifests`, type has to be `list[LiveDashManifest]`")

        self._dash_manifests = dash_manifests

    @property
    def live_encoding_mode(self):
        # type: () -> EncodingMode
        """Gets the live_encoding_mode of this StartLiveEncodingRequest.

        The pass mode of the encoding. Must only be set when `encodingMode` is not set on any codec configuration used by this encoding.

        :return: The live_encoding_mode of this StartLiveEncodingRequest.
        :rtype: EncodingMode
        """
        return self._live_encoding_mode

    @live_encoding_mode.setter
    def live_encoding_mode(self, live_encoding_mode):
        # type: (EncodingMode) -> None
        """Sets the live_encoding_mode of this StartLiveEncodingRequest.

        The pass mode of the encoding. Must only be set when `encodingMode` is not set on any codec configuration used by this encoding.

        :param live_encoding_mode: The live_encoding_mode of this StartLiveEncodingRequest.
        :type: EncodingMode
        """

        if live_encoding_mode is not None:
            if not isinstance(live_encoding_mode, EncodingMode):
                raise TypeError("Invalid type for `live_encoding_mode`, type has to be `EncodingMode`")

        self._live_encoding_mode = live_encoding_mode

    @property
    def reupload_settings(self):
        # type: () -> ReuploadSettings
        """Gets the reupload_settings of this StartLiveEncodingRequest.

        Reupload specific files during a live encoding. This can be helpful if an automatic life cycle policy is enabled on the output storage

        :return: The reupload_settings of this StartLiveEncodingRequest.
        :rtype: ReuploadSettings
        """
        return self._reupload_settings

    @reupload_settings.setter
    def reupload_settings(self, reupload_settings):
        # type: (ReuploadSettings) -> None
        """Sets the reupload_settings of this StartLiveEncodingRequest.

        Reupload specific files during a live encoding. This can be helpful if an automatic life cycle policy is enabled on the output storage

        :param reupload_settings: The reupload_settings of this StartLiveEncodingRequest.
        :type: ReuploadSettings
        """

        if reupload_settings is not None:
            if not isinstance(reupload_settings, ReuploadSettings):
                raise TypeError("Invalid type for `reupload_settings`, type has to be `ReuploadSettings`")

        self._reupload_settings = reupload_settings

    @property
    def manifest_generator(self):
        # type: () -> ManifestGenerator
        """Gets the manifest_generator of this StartLiveEncodingRequest.

        Major version of the manifest generator to be used for manifests referenced in this request (by properties dashManifests, dashManifests). `V2` is available for encoder versions 2.70.0 and above and is the recommended option. The default value depends on the sign-up date of your organization. See [documentation](https://developer.bitmovin.com/encoding/docs/manifest-generator-v2) page for a detailed explanation. 

        :return: The manifest_generator of this StartLiveEncodingRequest.
        :rtype: ManifestGenerator
        """
        return self._manifest_generator

    @manifest_generator.setter
    def manifest_generator(self, manifest_generator):
        # type: (ManifestGenerator) -> None
        """Sets the manifest_generator of this StartLiveEncodingRequest.

        Major version of the manifest generator to be used for manifests referenced in this request (by properties dashManifests, dashManifests). `V2` is available for encoder versions 2.70.0 and above and is the recommended option. The default value depends on the sign-up date of your organization. See [documentation](https://developer.bitmovin.com/encoding/docs/manifest-generator-v2) page for a detailed explanation. 

        :param manifest_generator: The manifest_generator of this StartLiveEncodingRequest.
        :type: ManifestGenerator
        """

        if manifest_generator is not None:
            if not isinstance(manifest_generator, ManifestGenerator):
                raise TypeError("Invalid type for `manifest_generator`, type has to be `ManifestGenerator`")

        self._manifest_generator = manifest_generator

    @property
    def auto_restart_configuration(self):
        # type: () -> AutoRestartConfiguration
        """Gets the auto_restart_configuration of this StartLiveEncodingRequest.

        Configuration for auto restarting the live encoding

        :return: The auto_restart_configuration of this StartLiveEncodingRequest.
        :rtype: AutoRestartConfiguration
        """
        return self._auto_restart_configuration

    @auto_restart_configuration.setter
    def auto_restart_configuration(self, auto_restart_configuration):
        # type: (AutoRestartConfiguration) -> None
        """Sets the auto_restart_configuration of this StartLiveEncodingRequest.

        Configuration for auto restarting the live encoding

        :param auto_restart_configuration: The auto_restart_configuration of this StartLiveEncodingRequest.
        :type: AutoRestartConfiguration
        """

        if auto_restart_configuration is not None:
            if not isinstance(auto_restart_configuration, AutoRestartConfiguration):
                raise TypeError("Invalid type for `auto_restart_configuration`, type has to be `AutoRestartConfiguration`")

        self._auto_restart_configuration = auto_restart_configuration

    @property
    def auto_shutdown_configuration(self):
        # type: () -> LiveAutoShutdownConfiguration
        """Gets the auto_shutdown_configuration of this StartLiveEncodingRequest.

        Configuration for auto shutdown of the live encoding

        :return: The auto_shutdown_configuration of this StartLiveEncodingRequest.
        :rtype: LiveAutoShutdownConfiguration
        """
        return self._auto_shutdown_configuration

    @auto_shutdown_configuration.setter
    def auto_shutdown_configuration(self, auto_shutdown_configuration):
        # type: (LiveAutoShutdownConfiguration) -> None
        """Sets the auto_shutdown_configuration of this StartLiveEncodingRequest.

        Configuration for auto shutdown of the live encoding

        :param auto_shutdown_configuration: The auto_shutdown_configuration of this StartLiveEncodingRequest.
        :type: LiveAutoShutdownConfiguration
        """

        if auto_shutdown_configuration is not None:
            if not isinstance(auto_shutdown_configuration, LiveAutoShutdownConfiguration):
                raise TypeError("Invalid type for `auto_shutdown_configuration`, type has to be `LiveAutoShutdownConfiguration`")

        self._auto_shutdown_configuration = auto_shutdown_configuration

    @property
    def esam_settings(self):
        # type: () -> EsamSettings
        """Gets the esam_settings of this StartLiveEncodingRequest.

        Configuration for Event Signaling and Management (ESAM) system,  allowing the encoder to communicate with an ESAM server for signal processing and dynamic ad insertion update.' 

        :return: The esam_settings of this StartLiveEncodingRequest.
        :rtype: EsamSettings
        """
        return self._esam_settings

    @esam_settings.setter
    def esam_settings(self, esam_settings):
        # type: (EsamSettings) -> None
        """Sets the esam_settings of this StartLiveEncodingRequest.

        Configuration for Event Signaling and Management (ESAM) system,  allowing the encoder to communicate with an ESAM server for signal processing and dynamic ad insertion update.' 

        :param esam_settings: The esam_settings of this StartLiveEncodingRequest.
        :type: EsamSettings
        """

        if esam_settings is not None:
            if not isinstance(esam_settings, EsamSettings):
                raise TypeError("Invalid type for `esam_settings`, type has to be `EsamSettings`")

        self._esam_settings = esam_settings

    @property
    def cache_control_settings(self):
        # type: () -> CacheControlSettings
        """Gets the cache_control_settings of this StartLiveEncodingRequest.

        Configuration of cache control policies for media segments, HLS, and DASH manifests.  You can set caching for the HLS multivariant playlist, HLS media playlist, DASH timeline manifest,  DASH template manifest, initialization segment, and media segment. 

        :return: The cache_control_settings of this StartLiveEncodingRequest.
        :rtype: CacheControlSettings
        """
        return self._cache_control_settings

    @cache_control_settings.setter
    def cache_control_settings(self, cache_control_settings):
        # type: (CacheControlSettings) -> None
        """Sets the cache_control_settings of this StartLiveEncodingRequest.

        Configuration of cache control policies for media segments, HLS, and DASH manifests.  You can set caching for the HLS multivariant playlist, HLS media playlist, DASH timeline manifest,  DASH template manifest, initialization segment, and media segment. 

        :param cache_control_settings: The cache_control_settings of this StartLiveEncodingRequest.
        :type: CacheControlSettings
        """

        if cache_control_settings is not None:
            if not isinstance(cache_control_settings, CacheControlSettings):
                raise TypeError("Invalid type for `cache_control_settings`, type has to be `CacheControlSettings`")

        self._cache_control_settings = cache_control_settings

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StartLiveEncodingRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
import pprint
import six


class CustomPlayerBuildDetails(BitmovinResource):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 player_version=None,
                 domains=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, string_types, list[string_types]) -> None
        super(CustomPlayerBuildDetails, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._player_version = None
        self._domains = list()
        self.discriminator = None

        if player_version is not None:
            self.player_version = player_version
        if domains is not None:
            self.domains = domains

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(CustomPlayerBuildDetails, self), 'openapi_types'):
            types = getattr(super(CustomPlayerBuildDetails, self), 'openapi_types')

        types.update({
            'player_version': 'string_types',
            'domains': 'list[string_types]'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(CustomPlayerBuildDetails, self), 'attribute_map'):
            attributes = getattr(super(CustomPlayerBuildDetails, self), 'attribute_map')

        attributes.update({
            'player_version': 'playerVersion',
            'domains': 'domains'
        })
        return attributes

    @property
    def player_version(self):
        # type: () -> string_types
        """Gets the player_version of this CustomPlayerBuildDetails.

        The player version that should be used for the custom player build. If not set the 'latest' version is used. (required)

        :return: The player_version of this CustomPlayerBuildDetails.
        :rtype: string_types
        """
        return self._player_version

    @player_version.setter
    def player_version(self, player_version):
        # type: (string_types) -> None
        """Sets the player_version of this CustomPlayerBuildDetails.

        The player version that should be used for the custom player build. If not set the 'latest' version is used. (required)

        :param player_version: The player_version of this CustomPlayerBuildDetails.
        :type: string_types
        """

        if player_version is not None:
            if not isinstance(player_version, string_types):
                raise TypeError("Invalid type for `player_version`, type has to be `string_types`")

        self._player_version = player_version

    @property
    def domains(self):
        # type: () -> list[string_types]
        """Gets the domains of this CustomPlayerBuildDetails.

        The domains that the player is locked to. If not set the player will only work with 'localhost'. Not more than 49 additional domains can be added. (required)

        :return: The domains of this CustomPlayerBuildDetails.
        :rtype: list[string_types]
        """
        return self._domains

    @domains.setter
    def domains(self, domains):
        # type: (list) -> None
        """Sets the domains of this CustomPlayerBuildDetails.

        The domains that the player is locked to. If not set the player will only work with 'localhost'. Not more than 49 additional domains can be added. (required)

        :param domains: The domains of this CustomPlayerBuildDetails.
        :type: list[string_types]
        """

        if domains is not None:
            if not isinstance(domains, list):
                raise TypeError("Invalid type for `domains`, type has to be `list[string_types]`")

        self._domains = domains

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(CustomPlayerBuildDetails, self), "to_dict"):
            result = super(CustomPlayerBuildDetails, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CustomPlayerBuildDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.live_standby_pool_event_log import LiveStandbyPoolEventLog
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.encoding.live.standby_pools.logs.live_standby_pool_event_log_list_query_params import LiveStandbyPoolEventLogListQueryParams


class LogsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(LogsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def list(self, pool_id, query_params=None, **kwargs):
        # type: (string_types, LiveStandbyPoolEventLogListQueryParams, dict) -> LiveStandbyPoolEventLog
        """List event logs for a standby pool

        :param pool_id: Id of the standby pool
        :type pool_id: string_types, required
        :param query_params: Query parameters
        :type query_params: LiveStandbyPoolEventLogListQueryParams
        :return: Standby pool event logs list response
        :rtype: LiveStandbyPoolEventLog
        """

        return self.api_client.get(
            '/encoding/live/standby-pools/{pool_id}/logs',
            path_params={'pool_id': pool_id},
            query_params=query_params,
            pagination_response=True,
            type=LiveStandbyPoolEventLog,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.dash_scte35_event_stream_signalling import DashScte35EventStreamSignalling
from bitmovin_api_sdk.models.dash_scte35_period_option import DashScte35PeriodOption
import pprint
import six


class DashManifestAdMarkerSettings(object):
    @poscheck_model
    def __init__(self,
                 period_option=None,
                 event_stream_signalling=None):
        # type: (DashScte35PeriodOption, DashScte35EventStreamSignalling) -> None

        self._period_option = None
        self._event_stream_signalling = None
        self.discriminator = None

        if period_option is not None:
            self.period_option = period_option
        if event_stream_signalling is not None:
            self.event_stream_signalling = event_stream_signalling

    @property
    def openapi_types(self):
        types = {
            'period_option': 'DashScte35PeriodOption',
            'event_stream_signalling': 'DashScte35EventStreamSignalling'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'period_option': 'periodOption',
            'event_stream_signalling': 'eventStreamSignalling'
        }
        return attributes

    @property
    def period_option(self):
        # type: () -> DashScte35PeriodOption
        """Gets the period_option of this DashManifestAdMarkerSettings.


        :return: The period_option of this DashManifestAdMarkerSettings.
        :rtype: DashScte35PeriodOption
        """
        return self._period_option

    @period_option.setter
    def period_option(self, period_option):
        # type: (DashScte35PeriodOption) -> None
        """Sets the period_option of this DashManifestAdMarkerSettings.


        :param period_option: The period_option of this DashManifestAdMarkerSettings.
        :type: DashScte35PeriodOption
        """

        if period_option is not None:
            if not isinstance(period_option, DashScte35PeriodOption):
                raise TypeError("Invalid type for `period_option`, type has to be `DashScte35PeriodOption`")

        self._period_option = period_option

    @property
    def event_stream_signalling(self):
        # type: () -> DashScte35EventStreamSignalling
        """Gets the event_stream_signalling of this DashManifestAdMarkerSettings.


        :return: The event_stream_signalling of this DashManifestAdMarkerSettings.
        :rtype: DashScte35EventStreamSignalling
        """
        return self._event_stream_signalling

    @event_stream_signalling.setter
    def event_stream_signalling(self, event_stream_signalling):
        # type: (DashScte35EventStreamSignalling) -> None
        """Sets the event_stream_signalling of this DashManifestAdMarkerSettings.


        :param event_stream_signalling: The event_stream_signalling of this DashManifestAdMarkerSettings.
        :type: DashScte35EventStreamSignalling
        """

        if event_stream_signalling is not None:
            if not isinstance(event_stream_signalling, DashScte35EventStreamSignalling):
                raise TypeError("Invalid type for `event_stream_signalling`, type has to be `DashScte35EventStreamSignalling`")

        self._event_stream_signalling = event_stream_signalling

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DashManifestAdMarkerSettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class H265DynamicRangeFormat(Enum):
    DOLBY_VISION = "DOLBY_VISION"
    DOLBY_VISION_PROFILE_5 = "DOLBY_VISION_PROFILE_5"
    DOLBY_VISION_PROFILE_8_1 = "DOLBY_VISION_PROFILE_8_1"
    HDR10 = "HDR10"
    HLG = "HLG"
    SDR = "SDR"



from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.cmaf.contentprotection.contentprotection_api import ContentprotectionApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.cmaf.contentprotection.content_protection_list_query_params import ContentProtectionListQueryParams



from bitmovin_api_sdk.encoding.configurations.video.vp9.vp9_api import Vp9Api
from bitmovin_api_sdk.encoding.configurations.video.vp9.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.configurations.video.vp9.vp9_video_configuration_list_query_params import Vp9VideoConfigurationListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class ProgramDateTimePlacementMode(Enum):
    ONCE_PER_PLAYLIST = "ONCE_PER_PLAYLIST"
    SEGMENTS_INTERVAL = "SEGMENTS_INTERVAL"
    SECONDS_INTERVAL = "SECONDS_INTERVAL"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class MaxTransformUnitSize(Enum):
    MTU_4x4 = "MTU_4x4"
    MTU_8x8 = "MTU_8x8"
    MTU_16x16 = "MTU_16x16"
    MTU_32x32 = "MTU_32x32"



from bitmovin_api_sdk.encoding.encodings.input_streams.captions.cea708.cea708_api import Cea708Api
from bitmovin_api_sdk.encoding.encodings.input_streams.captions.cea708.cea708_caption_input_stream_list_query_params import Cea708CaptionInputStreamListQueryParams



class CdnUsageStatisticsGetQueryParams(object):
    def __init__(self, from_=None, to=None):
        # type: (datetime, datetime) -> None
        super(CdnUsageStatisticsGetQueryParams, self).__init__()

        self.from_ = from_
        self.to = to

    @property
    def openapi_types(self):
        types = {
            'from_': 'datetime',
            'to': 'datetime'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'from_': 'from',
            'to': 'to'
        }

        return attributes
